/* automatically generated from applicationsmenu-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (applicationsmenu_dialog_ui)
#endif
#ifdef __GNUC__
static const char applicationsmenu_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char applicationsmenu_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">alacarte</property></object><object class=\"GtkImage\" "
  "id=\"image2\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"icon_name\">help-browser"
  "</property></object><object class=\"GtkImage\" id=\"image3\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"icon_name\">window-close</property></object><obj"
  "ect class=\"XfceTitledDialog\" id=\"dialog\"><property name=\"can_focus"
  "\">False</property><property name=\"title\" translatable=\"yes\">Applic"
  "ations Menu</property><property name=\"icon_name\">document-properties<"
  "/property><property name=\"type_hint\">normal</property><child internal"
  "-child=\"vbox\"><object class=\"GtkBox\" id=\"dialog-vbox2\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"orientation\">vertical</property><property name="
  "\"spacing\">2</property><child internal-child=\"action_area\"><object c"
  "lass=\"GtkButtonBox\" id=\"dialog-action_area2\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"layout_style\">end</property><child><object class=\"GtkButto"
  "n\" id=\"help-button\"><property name=\"label\" translatable=\"yes\">_H"
  "elp</property><property name=\"visible\">True</property><property name="
  "\"can_focus\">True</property><property name=\"receives_default\">True</"
  "property><property name=\"image\">image2</property><property name=\"use"
  "_underline\">True</property></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">False</property><property name"
  "=\"position\">0</property><property name=\"secondary\">True</property><"
  "/packing></child><child><object class=\"GtkButton\" id=\"close-button\""
  "><property name=\"label\" translatable=\"yes\">_Close</property><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"receives_default\">True</property><property na"
  "me=\"image\">image3</property><property name=\"use_underline\">True</pr"
  "operty></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">False</property><property name=\"position\">1</prop"
  "erty></packing></child></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">False</property><property name=\"pa"
  "ck_type\">end</property><property name=\"position\">0</property></packi"
  "ng></child><child><object class=\"GtkBox\" id=\"vbox1\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"border_width\">6</property><property name=\"orientati"
  "on\">vertical</property><property name=\"spacing\">6</property><child><"
  "object class=\"GtkFrame\" id=\"frame3\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"label_xalign\">0</property><property name=\"shadow_type\">none</prope"
  "rty><child><object class=\"GtkGrid\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"m"
  "argin_left\">18</property><property name=\"row_spacing\">6</property><p"
  "roperty name=\"column_spacing\">12</property><child><object class=\"Gtk"
  "Label\" id=\"label4\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"label\" translat"
  "able=\"yes\">_Icon:</property><property name=\"use_underline\">True</pr"
  "operty><property name=\"xalign\">0</property></object><packing><propert"
  "y name=\"left_attach\">0</property><property name=\"top_attach\">5</pro"
  "perty></packing></child><child><object class=\"GtkEntry\" id=\"button-t"
  "itle\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">True</property><property name=\"invisible_char\">\342\200\242</p"
  "roperty></object><packing><property name=\"left_attach\">1</property><p"
  "roperty name=\"top_attach\">4</property></packing></child><child><objec"
  "t class=\"GtkLabel\" id=\"label2\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"lab"
  "el\" translatable=\"yes\">Button _title:</property><property name=\"use"
  "_underline\">True</property><property name=\"xalign\">0</property></obj"
  "ect><packing><property name=\"left_attach\">0</property><property name="
  "\"top_attach\">4</property></packing></child><child><object class=\"Gtk"
  "CheckButton\" id=\"show-button-title\"><property name=\"label\" transla"
  "table=\"yes\">_Show button title</property><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">True</property><property nam"
  "e=\"receives_default\">False</property><property name=\"use_underline\""
  ">True</property><property name=\"draw_indicator\">True</property></obje"
  "ct><packing><property name=\"left_attach\">0</property><property name=\""
  "top_attach\">3</property><property name=\"width\">2</property></packing"
  "></child><child><object class=\"GtkCheckButton\" id=\"show-tooltips\"><"
  "property name=\"label\" translatable=\"yes\">Show application d_escript"
  "ion in tooltip</property><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">True</property><property name=\"receives_defau"
  "lt\">False</property><property name=\"use_underline\">True</property><p"
  "roperty name=\"image_position\">right</property><property name=\"draw_i"
  "ndicator\">True</property></object><packing><property name=\"left_attac"
  "h\">0</property><property name=\"top_attach\">2</property><property nam"
  "e=\"width\">2</property></packing></child><child><object class=\"GtkChe"
  "ckButton\" id=\"show-menu-icons\"><property name=\"label\" translatable"
  "=\"yes\">Show ic_ons in menu</property><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "receives_default\">False</property><property name=\"use_underline\">Tru"
  "e</property><property name=\"draw_indicator\">True</property></object><"
  "packing><property name=\"left_attach\">0</property><property name=\"top"
  "_attach\">1</property><property name=\"width\">2</property></packing></"
  "child><child><object class=\"GtkCheckButton\" id=\"show-generic-names\""
  "><property name=\"label\" translatable=\"yes\">Show generic application"
  " n_ames</property><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">True</property><property name=\"receives_default\">Fa"
  "lse</property><property name=\"tooltip_text\" translatable=\"yes\">Sele"
  "ct this option to show the generic application name in the menu, for ex"
  "ample \"File Manager\" instead of \"Thunar\"</property><property name=\""
  "use_underline\">True</property><property name=\"draw_indicator\">True</"
  "property></object><packing><property name=\"left_attach\">0</property><"
  "property name=\"top_attach\">0</property><property name=\"width\">2</pr"
  "operty></packing></child><child><object class=\"GtkButton\" id=\"icon-b"
  "utton\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">True</property><property name=\"receives_default\">True</proper"
  "ty><property name=\"halign\">start</property><child><placeholder/></chi"
  "ld></object><packing><property name=\"left_attach\">1</property><proper"
  "ty name=\"top_attach\">5</property></packing></child></object></child><"
  "child type=\"label\"><object class=\"GtkLabel\" id=\"label1\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"label\" translatable=\"yes\">Appearance</proper"
  "ty><attributes><attribute name=\"weight\" value=\"bold\"/></attributes>"
  "</object></child></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkFrame\" id=\"f"
  "rame1\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"label_xalign\">0</property><pr"
  "operty name=\"shadow_type\">none</property><child><object class=\"GtkAl"
  "ignment\" id=\"alignment1\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"left_paddi"
  "ng\">12</property><child><object class=\"GtkBox\" id=\"vbox2\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"border_width\">6</property><property name=\"or"
  "ientation\">vertical</property><property name=\"spacing\">6</property><"
  "child><object class=\"GtkBox\" id=\"hbox1\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"spacing\">12</property><child><object class=\"GtkRadioButton\" id"
  "=\"use-default-menu\"><property name=\"label\" translatable=\"yes\">Use"
  " the _default menu</property><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"receives_d"
  "efault\">False</property><property name=\"use_underline\">True</propert"
  "y><property name=\"draw_indicator\">True</property></object><packing><p"
  "roperty name=\"expand\">False</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkButton\" id=\"edit-menu-button\"><property name=\""
  "label\" translatable=\"yes\">Ed_it Menu</property><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"receives_default\">True</property><property name=\"image\">i"
  "mage1</property><property name=\"use_underline\">True</property></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">True</property><property name=\"position\">1</property></packing>"
  "</child></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">True</property><property name=\"position\">0</prop"
  "erty></packing></child><child><object class=\"GtkRadioButton\" id=\"use"
  "-custom-menu\"><property name=\"label\" translatable=\"yes\">Use c_usto"
  "m menu file:</property><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">True</property><property name=\"receives_default"
  "\">False</property><property name=\"use_underline\">True</property><pro"
  "perty name=\"active\">True</property><property name=\"draw_indicator\">"
  "True</property><property name=\"group\">use-default-menu</property></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"position\">1</property></packi"
  "ng></child><child><object class=\"GtkAlignment\" id=\"alignment5\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"left_padding\">22</property><child><object"
  " class=\"GtkHBox\" id=\"custom-box\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"s"
  "pacing\">12</property><child><object class=\"GtkLabel\" id=\"label5\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><property name=\"label\" translatable=\"yes\">Menu _file"
  ":</property><property name=\"use_underline\">True</property></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkFileChooserButton\" id=\"custom-file\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"title\" translatable=\"yes\">Select A Men"
  "u File</property></object><packing><property name=\"expand\">True</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">1</property></packing></child></object></child></object><packing><prop"
  "erty name=\"expand\">False</property><property name=\"fill\">True</prop"
  "erty><property name=\"position\">2</property></packing></child></object"
  "></child></object></child><child type=\"label\"><object class=\"GtkLabe"
  "l\" id=\"label3\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label\" translatable"
  "=\"yes\">Menu File</property><attributes><attribute name=\"weight\" val"
  "ue=\"bold\"/></attributes></object></child></object><packing><property "
  "name=\"expand\">False</property><property name=\"fill\">True</property>"
  "<property name=\"position\">1</property></packing></child></object><pac"
  "king><property name=\"expand\">False</property><property name=\"fill\">"
  "True</property><property name=\"position\">1</property></packing></chil"
  "d></object></child><action-widgets><action-widget response=\"0\">help-b"
  "utton</action-widget><action-widget response=\"0\">close-button</action"
  "-widget></action-widgets></object><object class=\"GtkSizeGroup\" id=\"s"
  "izegroup1\"/></interface>"
};

static const unsigned applicationsmenu_dialog_ui_length = 12121u;

