/* automatically generated from pager-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (pager_dialog_ui)
#endif
#ifdef __GNUC__
static const char pager_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char pager_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">xfce4-workspaces</property></object><object class=\"Gtk"
  "Image\" id=\"image2\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"icon_name\">help"
  "-browser</property></object><object class=\"GtkImage\" id=\"image3\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"icon_name\">window-close</property></obj"
  "ect><object class=\"GtkAdjustment\" id=\"rows\"><property name=\"lower\""
  ">1</property><property name=\"upper\">10</property><property name=\"val"
  "ue\">1</property><property name=\"step_increment\">1</property><propert"
  "y name=\"page_increment\">10</property></object><object class=\"XfceTit"
  "ledDialog\" id=\"dialog\"><property name=\"can_focus\">False</property>"
  "<property name=\"title\" translatable=\"yes\">Workspace Switcher</prope"
  "rty><property name=\"icon_name\">document-properties</property><propert"
  "y name=\"type_hint\">normal</property><child internal-child=\"vbox\"><o"
  "bject class=\"GtkBox\" id=\"dialog-vbox2\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"orientation\">vertical</property><property name=\"spacing\">2</pro"
  "perty><child internal-child=\"action_area\"><object class=\"GtkButtonBo"
  "x\" id=\"dialog-action_area2\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"layout_"
  "style\">end</property><child><object class=\"GtkButton\" id=\"close-but"
  "ton\"><property name=\"label\" translatable=\"yes\">_Close</property><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Tr"
  "ue</property><property name=\"receives_default\">True</property><proper"
  "ty name=\"image\">image3</property><property name=\"use_underline\">Tru"
  "e</property></object><packing><property name=\"expand\">False</property"
  "><property name=\"fill\">False</property><property name=\"position\">0<"
  "/property></packing></child><child><object class=\"GtkButton\" id=\"hel"
  "p-button\"><property name=\"label\" translatable=\"yes\">_Help</propert"
  "y><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"receives_default\">True</property><pro"
  "perty name=\"image\">image2</property><property name=\"use_underline\">"
  "True</property></object><packing><property name=\"expand\">False</prope"
  "rty><property name=\"fill\">False</property><property name=\"position\""
  ">1</property><property name=\"secondary\">True</property></packing></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">False</property><property name=\"pack_type\">end</prop"
  "erty><property name=\"position\">0</property></packing></child><child><"
  "object class=\"GtkBox\" id=\"vbox2\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"b"
  "order_width\">6</property><property name=\"orientation\">vertical</prop"
  "erty><property name=\"spacing\">6</property><child><object class=\"GtkF"
  "rame\" id=\"frame2\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"label_xalign\">0<"
  "/property><property name=\"shadow_type\">none</property><child><object "
  "class=\"GtkAlignment\" id=\"alignment2\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"left_padding\">12</property><child><object class=\"GtkBox\" id=\"vbo"
  "x4\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"border_width\">6</property><prope"
  "rty name=\"orientation\">vertical</property><property name=\"spacing\">"
  "6</property><child><object class=\"GtkBox\" id=\"hbox3\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y><property name=\"spacing\">12</property><child><object class=\"GtkLab"
  "el\" id=\"label4\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"label\" translatabl"
  "e=\"yes\">Number of _rows:</property><property name=\"use_underline\">T"
  "rue</property><property name=\"mnemonic_widget\">spin1</property></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">0</property></packing"
  "></child><child><object class=\"GtkSpinButton\" id=\"spin1\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">True</prop"
  "erty><property name=\"adjustment\">rows</property><property name=\"snap"
  "_to_ticks\">True</property><property name=\"numeric\">True</property><p"
  "roperty name=\"update_policy\">if-valid</property></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">True</pr"
  "operty><property name=\"position\">1</property></packing></child></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">0</property></packing"
  "></child><child><object class=\"GtkCheckButton\" id=\"miniature-view\">"
  "<property name=\"label\" translatable=\"yes\">Show mi_niature view</pro"
  "perty><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">True</property><property name=\"receives_default\">False</propert"
  "y><property name=\"tooltip_text\" translatable=\"yes\">Show a miniature"
  " view of the workspace with rectangles for the visible windows</propert"
  "y><property name=\"use_underline\">True</property><property name=\"draw"
  "_indicator\">True</property></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">1</property></packing></child><child><object class=\"GtkAl"
  "ignment\" id=\"alignment1\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"xalign\">0"
  "</property><property name=\"xscale\">0</property><child><object class=\""
  "GtkButton\" id=\"settings-button\"><property name=\"label\" translatabl"
  "e=\"yes\">Workspace _Settings...</property><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">True</property><property nam"
  "e=\"receives_default\">True</property><property name=\"image\">image1</"
  "property><property name=\"use_underline\">True</property></object></chi"
  "ld></object><packing><property name=\"expand\">False</property><propert"
  "y name=\"fill\">True</property><property name=\"position\">2</property>"
  "</packing></child></object></child></object></child><child type=\"label"
  "\"><object class=\"GtkLabel\" id=\"label5\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label\" translatable=\"yes\">Appearance</property><attributes><at"
  "tribute name=\"weight\" value=\"bold\"/></attributes></object></child><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">True</property><property name=\"position\">0</property></pa"
  "cking></child><child><object class=\"GtkFrame\" id=\"frame3\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"label_xalign\">0</property><property name=\"sha"
  "dow_type\">none</property><child><object class=\"GtkAlignment\" id=\"al"
  "ignment3\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"top_padding\">6</property><"
  "property name=\"bottom_padding\">6</property><property name=\"left_padd"
  "ing\">18</property><property name=\"right_padding\">6</property><child>"
  "<object class=\"GtkCheckButton\" id=\"workspace-scrolling\"><property n"
  "ame=\"label\" translatable=\"yes\">Switch workspaces using the mouse _w"
  "heel</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">False"
  "</property><property name=\"use_underline\">True</property><property na"
  "me=\"draw_indicator\">True</property></object></child></object></child>"
  "<child type=\"label\"><object class=\"GtkLabel\" id=\"label7\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"label\" translatable=\"yes\">Behaviour</proper"
  "ty><attributes><attribute name=\"weight\" value=\"bold\"/></attributes>"
  "</object></child></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">1</property></packing></child></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">True</property><property na"
  "me=\"position\">1</property></packing></child></object></child><action-"
  "widgets><action-widget response=\"0\">close-button</action-widget><acti"
  "on-widget response=\"0\">help-button</action-widget></action-widgets></"
  "object></interface>"
};

static const unsigned pager_dialog_ui_length = 8466u;

