/* automatically generated from launcher-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (launcher_dialog_ui)
#endif
#ifdef __GNUC__
static const char launcher_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char launcher_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkListStore\" id=\"add-store\"><columns><column type="
  "\"GdkPixbuf\"/><column type=\"gchararray\"/><column type=\"GObject\"/><"
  "column type=\"gchararray\"/><column type=\"gchararray\"/></columns></ob"
  "ject><object class=\"GtkTreeModelFilter\" id=\"add-store-filter\"><prop"
  "erty name=\"child_model\">add-store</property></object><object class=\""
  "GtkListStore\" id=\"arrow-position-model\"><columns><column type=\"gcha"
  "rarray\"/></columns><data><row><col id=\"0\" translatable=\"yes\">Defau"
  "lt</col></row><row><col id=\"0\" translatable=\"yes\">North</col></row>"
  "<row><col id=\"0\" translatable=\"yes\">West</col></row><row><col id=\""
  "0\" translatable=\"yes\">East</col></row><row><col id=\"0\" translatabl"
  "e=\"yes\">South</col></row><row><col id=\"0\" translatable=\"yes\">Insi"
  "de Button</col></row></data></object><object class=\"GtkImage\" id=\"im"
  "age11\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"icon_name\">accessories-text-e"
  "ditor</property><property name=\"icon_size\">1</property></object><obje"
  "ct class=\"GtkImage\" id=\"image12\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"i"
  "con_name\">edit-delete</property><property name=\"icon_size\">1</proper"
  "ty></object><object class=\"GtkImage\" id=\"image13\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"icon_name\">document-new</property><property name=\"ico"
  "n_size\">1</property></object><object class=\"GtkImage\" id=\"image14\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"icon_name\">applications-internet</pr"
  "operty><property name=\"icon_size\">1</property></object><object class="
  "\"GtkImage\" id=\"image15\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"icon_name\""
  ">list-add</property><property name=\"icon_size\">1</property></object><"
  "object class=\"GtkImage\" id=\"image16\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"icon_name\">go-up</property><property name=\"icon_size\">1</property"
  "></object><object class=\"GtkImage\" id=\"image17\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"icon_name\">go-up</property></object><object class=\"GtkI"
  "mage\" id=\"image18\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"icon_name\">go-d"
  "own</property><property name=\"icon_size\">1</property></object><object"
  " class=\"GtkMenu\" id=\"popup-menu\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><child><object cla"
  "ss=\"GtkImageMenuItem\" id=\"mi-move-up\"><property name=\"label\" tran"
  "slatable=\"yes\">Up</property><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"image\">"
  "image16</property><property name=\"use_stock\">False</property></object"
  "></child><child><object class=\"GtkImageMenuItem\" id=\"mi-move-down\">"
  "<property name=\"label\" translatable=\"yes\">Down</property><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"image\">image18</property><property name=\"use_s"
  "tock\">False</property></object></child><child><object class=\"GtkSepar"
  "atorMenuItem\" id=\"smi1\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property></object></child><child><obj"
  "ect class=\"GtkImageMenuItem\" id=\"mi-edit\"><property name=\"label\" "
  "translatable=\"yes\">_Edit Item</property><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"use_underline\">True</property><property name=\"image\">image11</pr"
  "operty><property name=\"use_stock\">False</property></object></child><c"
  "hild><object class=\"GtkImageMenuItem\" id=\"mi-delete\"><property name"
  "=\"label\" translatable=\"yes\">D_elete Item</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"use_underline\">True</property><property name=\"image\""
  ">image12</property><property name=\"use_stock\">False</property></objec"
  "t></child><child><object class=\"GtkSeparatorMenuItem\" id=\"smi2\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property></object></child><child><object class=\"GtkImageMenuItem\""
  " id=\"mi-add\"><property name=\"label\" translatable=\"yes\">Add Appli_"
  "cation</property><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"use_underline\">True<"
  "/property><property name=\"image\">image15</property><property name=\"u"
  "se_stock\">False</property></object></child><child><object class=\"GtkS"
  "eparatorMenuItem\" id=\"smi3\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property></object></child><child>"
  "<object class=\"GtkImageMenuItem\" id=\"mi-application\"><property name"
  "=\"label\" translatable=\"yes\">New _Application</property><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"use_underline\">True</property><property name=\"im"
  "age\">image13</property><property name=\"use_stock\">False</property></"
  "object></child><child><object class=\"GtkImageMenuItem\" id=\"mi-link\""
  "><property name=\"label\" translatable=\"yes\">New _Link</property><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"use_underline\">True</property><property n"
  "ame=\"image\">image14</property><property name=\"use_stock\">False</pro"
  "perty></object></child></object><object class=\"GtkImage\" id=\"image19"
  "\"><property name=\"visible\">True</property><property name=\"can_focus"
  "\">False</property><property name=\"icon_name\">list-add</property></ob"
  "ject><object class=\"GtkImage\" id=\"image6\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"icon_name\">help-browser</property></object><object class=\"GtkI"
  "mage\" id=\"image7\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"icon_name\">windo"
  "w-close</property></object><object class=\"XfceTitledDialog\" id=\"dial"
  "og-add\"><property name=\"can_focus\">False</property><property name=\""
  "title\" translatable=\"yes\">Add New Item</property><property name=\"wi"
  "ndow_position\">center-on-parent</property><property name=\"default_wid"
  "th\">400</property><property name=\"default_height\">400</property><pro"
  "perty name=\"destroy_with_parent\">True</property><property name=\"icon"
  "_name\">list-add</property><property name=\"type_hint\">normal</propert"
  "y><property name=\"subtitle\" translatable=\"yes\">Add one or more exis"
  "ting items to the launcher</property><child internal-child=\"vbox\"><ob"
  "ject class=\"GtkBox\" id=\"dialog-vbox4\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"orientation\">vertical</property><property name=\"spacing\">2</prop"
  "erty><child internal-child=\"action_area\"><object class=\"GtkButtonBox"
  "\" id=\"dialog-action_area4\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"layout_s"
  "tyle\">end</property><child><object class=\"GtkButton\" id=\"button-add"
  "\"><property name=\"label\" translatable=\"yes\">_Add</property><proper"
  "ty name=\"visible\">True</property><property name=\"sensitive\">False</"
  "property><property name=\"can_focus\">True</property><property name=\"r"
  "eceives_default\">True</property><property name=\"image\">image19</prop"
  "erty><property name=\"use_underline\">True</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">False"
  "</property><property name=\"position\">0</property></packing></child><c"
  "hild><object class=\"GtkButton\" id=\"button5\"><property name=\"label\""
  " translatable=\"yes\">_Close</property><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "receives_default\">True</property><property name=\"image\">image7</prop"
  "erty><property name=\"use_underline\">True</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">False"
  "</property><property name=\"position\">1</property></packing></child></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">False</property><property name=\"pack_type\">end</property><"
  "property name=\"position\">0</property></packing></child><child><object"
  " class=\"GtkBox\" id=\"vbox2\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"border_"
  "width\">6</property><property name=\"orientation\">vertical</property><"
  "property name=\"spacing\">6</property><child><object class=\"GtkBox\" i"
  "d=\"hbox4\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"spacing\">6</property><chi"
  "ld><object class=\"GtkLabel\" id=\"label4\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label\" translatable=\"yes\">_Search:</property><property name=\""
  "use_underline\">True</property><property name=\"xalign\">1</property></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">True</property><property name=\"position\">0</property></pac"
  "king></child><child><object class=\"GtkEntry\" id=\"add-search\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">True</"
  "property></object><packing><property name=\"expand\">False</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">1</pro"
  "perty></packing></child></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">0</property></packing></child><child><object class=\"GtkScroll"
  "edWindow\" id=\"scrolledwindow1\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">True</property><property name=\"vexpa"
  "nd\">True</property><property name=\"shadow_type\">etched-in</property>"
  "<child><object class=\"GtkTreeView\" id=\"add-treeview\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"model\">add-store-filter</property><property name=\"h"
  "eaders_visible\">False</property><property name=\"rules_hint\">True</pr"
  "operty><property name=\"enable_search\">False</property><property name="
  "\"tooltip_column\">3</property><child internal-child=\"selection\"><obj"
  "ect class=\"GtkTreeSelection\"/></child><child><object class=\"GtkTreeV"
  "iewColumn\" id=\"treeviewcolumn1\"><property name=\"spacing\">2</proper"
  "ty><child><object class=\"GtkCellRendererPixbuf\" id=\"addrenderericon\""
  "/><attributes><attribute name=\"pixbuf\">0</attribute></attributes></ch"
  "ild><child><object class=\"GtkCellRendererText\" id=\"addrenderername\""
  "/><attributes><attribute name=\"markup\">1</attribute></attributes></ch"
  "ild></object></child></object></child></object><packing><property name="
  "\"expand\">True</property><property name=\"fill\">True</property><prope"
  "rty name=\"position\">1</property></packing></child></object><packing><"
  "property name=\"expand\">True</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">1</property></packing></child></obj"
  "ect></child><action-widgets><action-widget response=\"1\">button-add</a"
  "ction-widget><action-widget response=\"0\">button5</action-widget></act"
  "ion-widgets></object><object class=\"GtkImage\" id=\"image8\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"icon_name\">window-close</property></object><ob"
  "ject class=\"GtkListStore\" id=\"item-store\"><columns><column type=\"G"
  "dkPixbuf\"/><column type=\"gchararray\"/><column type=\"GObject\"/><col"
  "umn type=\"gchararray\"/></columns></object><object class=\"XfceTitledD"
  "ialog\" id=\"dialog\"><property name=\"can_focus\">False</property><pro"
  "perty name=\"title\" translatable=\"yes\">Launcher</property><property "
  "name=\"window_position\">center</property><property name=\"default_widt"
  "h\">350</property><property name=\"default_height\">400</property><prop"
  "erty name=\"icon_name\">document-properties</property><property name=\""
  "type_hint\">normal</property><child internal-child=\"vbox\"><object cla"
  "ss=\"GtkBox\" id=\"dialog-vbox2\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"orie"
  "ntation\">vertical</property><property name=\"spacing\">2</property><ch"
  "ild internal-child=\"action_area\"><object class=\"GtkButtonBox\" id=\""
  "dialog-action_area2\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"layout_style\">e"
  "nd</property><child><object class=\"GtkButton\" id=\"help-button\"><pro"
  "perty name=\"label\" translatable=\"yes\">_Help</property><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">True</propert"
  "y><property name=\"receives_default\">True</property><property name=\"i"
  "mage\">image6</property><property name=\"use_underline\">True</property"
  "></object><packing><property name=\"expand\">False</property><property "
  "name=\"fill\">False</property><property name=\"position\">0</property><"
  "property name=\"secondary\">True</property></packing></child><child><ob"
  "ject class=\"GtkButton\" id=\"button2\"><property name=\"label\" transl"
  "atable=\"yes\">_Close</property><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">True</property><property name=\"receive"
  "s_default\">True</property><property name=\"image\">image8</property><p"
  "roperty name=\"use_underline\">True</property></object><packing><proper"
  "ty name=\"expand\">False</property><property name=\"fill\">False</prope"
  "rty><property name=\"position\">1</property></packing></child></object>"
  "<packing><property name=\"expand\">False</property><property name=\"fil"
  "l\">False</property><property name=\"pack_type\">end</property><propert"
  "y name=\"position\">0</property></packing></child><child><object class="
  "\"GtkNotebook\" id=\"notebook2\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">True</property><property name=\"vexpan"
  "d\">True</property><property name=\"border_width\">6</property><child><"
  "object class=\"GtkBox\" id=\"hbox1\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"b"
  "order_width\">6</property><property name=\"spacing\">6</property><child"
  "><object class=\"GtkScrolledWindow\" id=\"scrolledwindow2\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">True</prope"
  "rty><property name=\"hexpand\">True</property><property name=\"shadow_t"
  "ype\">etched-in</property><child><object class=\"GtkTreeView\" id=\"ite"
  "m-treeview\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"model\">item-store</propert"
  "y><property name=\"headers_visible\">False</property><property name=\"r"
  "ules_hint\">True</property><property name=\"enable_search\">False</prop"
  "erty><property name=\"tooltip_column\">3</property><child internal-chil"
  "d=\"selection\"><object class=\"GtkTreeSelection\"/></child><child><obj"
  "ect class=\"GtkTreeViewColumn\" id=\"treeviewcolumn2\"><property name=\""
  "spacing\">2</property><child><object class=\"GtkCellRendererPixbuf\" id"
  "=\"itemrenderericon\"/><attributes><attribute name=\"pixbuf\">0</attrib"
  "ute></attributes></child><child><object class=\"GtkCellRendererText\" i"
  "d=\"itemrenderername\"/><attributes><attribute name=\"markup\">1</attri"
  "bute></attributes></child></object></child></object></child></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkBox\" id=\"vbox3\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"orientation\">vertical</property><property name=\"spacing\">6"
  "</property><child><object class=\"GtkBox\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"orientation\">vertical</property><child><object class=\"GtkButton\""
  " id=\"item-move-up\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">True</property><property name=\"receives_default\""
  ">True</property><property name=\"tooltip_text\" translatable=\"yes\">Mo"
  "ve currently selected item up by one row</property><child><object class"
  "=\"GtkImage\" id=\"image2\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"icon_name\""
  ">go-up</property></object></child></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">True</property><property"
  " name=\"position\">0</property></packing></child><child><object class=\""
  "GtkButton\" id=\"item-move-down\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">True</property><property name=\"recei"
  "ves_default\">True</property><property name=\"tooltip_text\" translatab"
  "le=\"yes\">Move currently selected item down by one row</property><chil"
  "d><object class=\"GtkImage\" id=\"image3\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"icon_name\">go-down</property></object></child></object><packing><"
  "property name=\"expand\">False</property><property name=\"fill\">True</"
  "property><property name=\"position\">1</property></packing></child><sty"
  "le><class name=\"linked\"/></style></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">0</property></packing></child><child><object class="
  "\"GtkButton\" id=\"item-edit\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">True</property><property name=\"receives"
  "_default\">True</property><property name=\"tooltip_text\" translatable="
  "\"yes\">Edit the currently selected item</property><child><object class"
  "=\"GtkImage\" id=\"image1\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"icon_name\""
  ">accessories-text-editor</property></object></child></object><packing><"
  "property name=\"expand\">False</property><property name=\"fill\">True</"
  "property><property name=\"position\">1</property></packing></child><chi"
  "ld><object class=\"GtkButton\" id=\"item-delete\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"receives_default\">True</property><property name=\"tooltip_t"
  "ext\" translatable=\"yes\">Delete the currently selected item</property"
  "><child><object class=\"GtkImage\" id=\"image9\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"icon_name\">edit-delete</property></object></child></object>"
  "<packing><property name=\"expand\">False</property><property name=\"fil"
  "l\">True</property><property name=\"position\">3</property></packing></"
  "child><child><object class=\"GtkButton\" id=\"item-add\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"receives_default\">True</property><property name=\"to"
  "oltip_text\" translatable=\"yes\">Add one or more existing items to the"
  " launcher</property><child><object class=\"GtkImage\" id=\"image4\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"icon_name\">list-add</property></object><"
  "/child></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">True</property><property name=\"position\">4</prope"
  "rty></packing></child><child><object class=\"GtkButton\" id=\"item-new\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"receives_default\">True</property><pro"
  "perty name=\"tooltip_text\" translatable=\"yes\">Add a new empty item</"
  "property><child><object class=\"GtkImage\" id=\"image10\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"icon_name\">document-new</property></object></child"
  "></object><packing><property name=\"expand\">False</property><property "
  "name=\"fill\">True</property><property name=\"position\">4</property></"
  "packing></child><child><object class=\"GtkButton\" id=\"item-link\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Tru"
  "e</property><property name=\"receives_default\">True</property><propert"
  "y name=\"tooltip_text\" translatable=\"yes\">Add a new hyperlink</prope"
  "rty><child><object class=\"GtkImage\" id=\"image5\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"icon_name\">applications-internet</property></object></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">5</property"
  "></packing></child></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">1</property></packing></child></object></child><child type=\"tab\">"
  "<object class=\"GtkLabel\" id=\"label1\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"label\" translatable=\"yes\">General</property></object><packing><pr"
  "operty name=\"tab_fill\">False</property></packing></child><child><obje"
  "ct class=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"borde"
  "r_width\">6</property><property name=\"orientation\">vertical</property"
  "><property name=\"spacing\">6</property><child><object class=\"GtkCheck"
  "Button\" id=\"disable-tooltips\"><property name=\"label\" translatable="
  "\"yes\">Disable t_ooltips</property><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">True</property><property name=\"rec"
  "eives_default\">False</property><property name=\"tooltip_text\" transla"
  "table=\"yes\">Select this option to disable the tooltips when moving ov"
  "er the panel button or menu items.</property><property name=\"use_under"
  "line\">True</property><property name=\"draw_indicator\">True</property>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">0</property></p"
  "acking></child><child><object class=\"GtkCheckButton\" id=\"show-label\""
  "><property name=\"label\" translatable=\"yes\">Show _label instead of i"
  "con</property><property name=\"visible\">True</property><property name="
  "\"can_focus\">True</property><property name=\"receives_default\">False<"
  "/property><property name=\"use_underline\">True</property><property nam"
  "e=\"draw_indicator\">True</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">1</property></packing></child><child><object class"
  "=\"GtkCheckButton\" id=\"move-first\"><property name=\"label\" translat"
  "able=\"yes\">Show last _used item in panel</property><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">True</property><pr"
  "operty name=\"receives_default\">False</property><property name=\"toolt"
  "ip_text\" translatable=\"yes\">Select this option to move the clicked m"
  "enu item to the panel.</property><property name=\"use_underline\">True<"
  "/property><property name=\"draw_indicator\">True</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">2</property></packing></chi"
  "ld><child><object class=\"GtkBox\" id=\"hbox2\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"spacing\">12</property><child><object class=\"GtkLabel\" id=\""
  "arrow-position-label\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"label\" transla"
  "table=\"yes\">_Arrow button position:</property><property name=\"use_un"
  "derline\">True</property></object><packing><property name=\"expand\">Fa"
  "lse</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">0</property></packing></child><child><object class=\"GtkCombo"
  "Box\" id=\"arrow-position\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"model\">ar"
  "row-position-model</property><child><object class=\"GtkCellRendererText"
  "\" id=\"cellrenderertext1\"/><attributes><attribute name=\"text\">0</at"
  "tribute></attributes></child></object><packing><property name=\"expand\""
  ">True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object><packing><property na"
  "me=\"expand\">False</property><property name=\"fill\">True</property><p"
  "roperty name=\"position\">3</property></packing></child></object><packi"
  "ng><property name=\"position\">1</property></packing></child><child typ"
  "e=\"tab\"><object class=\"GtkLabel\" id=\"label5\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"label\" translatable=\"yes\">Advanced</property></object><"
  "packing><property name=\"position\">1</property><property name=\"tab_fi"
  "ll\">False</property></packing></child></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">1</property></packing></child></object></child>"
  "<action-widgets><action-widget response=\"1\">help-button</action-widge"
  "t><action-widget response=\"0\">button2</action-widget></action-widgets"
  "></object></interface>"
};

static const unsigned launcher_dialog_ui_length = 24436u;

