/* automatically generated from separator-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (separator_dialog_ui)
#endif
#ifdef __GNUC__
static const char separator_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char separator_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">help-browser</property></object><object class=\"GtkImag"
  "e\" id=\"image2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">window-c"
  "lose</property></object><object class=\"GtkListStore\" id=\"style-model"
  "\"><columns><column type=\"gchararray\"/></columns><data><row><col id=\""
  "0\" translatable=\"yes\">Transparent</col></row><row><col id=\"0\" tran"
  "slatable=\"yes\">Separator</col></row><row><col id=\"0\" translatable=\""
  "yes\">Handle</col></row><row><col id=\"0\" translatable=\"yes\">Dots</c"
  "ol></row></data></object><object class=\"XfceTitledDialog\" id=\"dialog"
  "\"><property name=\"can_focus\">False</property><property name=\"title\""
  " translatable=\"yes\">Separator</property><property name=\"icon_name\">"
  "document-properties</property><property name=\"type_hint\">normal</prop"
  "erty><child internal-child=\"vbox\"><object class=\"GtkBox\" id=\"dialo"
  "g-vbox2\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"orientation\">vertical</prop"
  "erty><property name=\"spacing\">2</property><child internal-child=\"act"
  "ion_area\"><object class=\"GtkButtonBox\" id=\"dialog-action_area2\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"layout_style\">end</property><child><obj"
  "ect class=\"GtkButton\" id=\"close-button\"><property name=\"label\" tr"
  "anslatable=\"yes\">_Close</property><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">True</property><property name=\"rec"
  "eives_default\">True</property><property name=\"image\">image2</propert"
  "y><property name=\"use_underline\">True</property></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">False</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkButton\" id=\"help-button\"><property name=\"label"
  "\" translatable=\"yes\">_Help</property><property name=\"visible\">True"
  "</property><property name=\"can_focus\">True</property><property name=\""
  "receives_default\">True</property><property name=\"image\">image1</prop"
  "erty><property name=\"use_underline\">True</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">False"
  "</property><property name=\"position\">1</property><property name=\"sec"
  "ondary\">True</property></packing></child></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">False</property>"
  "<property name=\"pack_type\">end</property><property name=\"position\">"
  "0</property></packing></child><child><object class=\"GtkFrame\" id=\"fr"
  "ame1\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"border_width\">6</property><pro"
  "perty name=\"label_xalign\">0</property><property name=\"shadow_type\">"
  "none</property><child><object class=\"GtkAlignment\" id=\"alignment1\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"left_padding\">12</property><child><ob"
  "ject class=\"GtkBox\" id=\"vbox3\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"bor"
  "der_width\">6</property><property name=\"orientation\">vertical</proper"
  "ty><property name=\"spacing\">6</property><child><object class=\"GtkBox"
  "\" id=\"hbox1\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"spacing\">12</property"
  "><child><object class=\"GtkLabel\" id=\"label2\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"label\" translatable=\"yes\">_Style:</property><property nam"
  "e=\"use_underline\">True</property><property name=\"mnemonic_widget\">s"
  "tyle</property></object><packing><property name=\"expand\">False</prope"
  "rty><property name=\"fill\">True</property><property name=\"position\">"
  "0</property></packing></child><child><object class=\"GtkComboBox\" id=\""
  "style\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"model\">style-model</property>"
  "<child><object class=\"GtkCellRendererText\" id=\"cellrenderertext1\"/>"
  "<attributes><attribute name=\"text\">0</attribute></attributes></child>"
  "</object><packing><property name=\"expand\">True</property><property na"
  "me=\"fill\">True</property><property name=\"position\">1</property></pa"
  "cking></child></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">True</property><property name=\"position\">0"
  "</property></packing></child><child><object class=\"GtkCheckButton\" id"
  "=\"expand\"><property name=\"label\" translatable=\"yes\">_Expand</prop"
  "erty><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">True</property><property name=\"receives_default\">False</property"
  "><property name=\"use_underline\">True</property><property name=\"draw_"
  "indicator\">True</property></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object></child></object></ch"
  "ild><child type=\"label\"><object class=\"GtkLabel\" id=\"label1\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"label\" translatable=\"yes\">Appearance</p"
  "roperty><attributes><attribute name=\"weight\" value=\"bold\"/></attrib"
  "utes></object></child></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">1</property></packing></child></object></child><action-widgets><"
  "action-widget response=\"0\">close-button</action-widget><action-widget"
  " response=\"0\">help-button</action-widget></action-widgets></object></"
  "interface>"
};

static const unsigned separator_dialog_ui_length = 5749u;

