/* automatically generated from tasklist-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (tasklist_dialog_ui)
#endif
#ifdef __GNUC__
static const char tasklist_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char tasklist_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkListStore\" id=\"grouping-model\"><columns><column "
  "type=\"gchararray\"/></columns><data><row><col id=\"0\" translatable=\""
  "yes\">Never</col></row><row><col id=\"0\" translatable=\"yes\">Always</"
  "col></row><row><col id=\"0\" translatable=\"yes\">When space is limited"
  "</col></row></data></object><object class=\"GtkImage\" id=\"image1\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"icon_name\">help-browser</property></obj"
  "ect><object class=\"GtkImage\" id=\"image2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"icon_name\">window-close</property></object><object class=\"GtkL"
  "istStore\" id=\"middle-click-model\"><columns><column type=\"gchararray"
  "\"/></columns><data><row><col id=\"0\" translatable=\"yes\">Nothing</co"
  "l></row><row><col id=\"0\" translatable=\"yes\">Close Window</col></row"
  "><row><col id=\"0\" translatable=\"yes\">Minimize Window</col></row></d"
  "ata></object><object class=\"GtkListStore\" id=\"sort-order-model\"><co"
  "lumns><column type=\"gchararray\"/></columns><data><row><col id=\"0\" t"
  "ranslatable=\"yes\">Timestamp</col></row><row><col id=\"0\" translatabl"
  "e=\"yes\">Group title and timestamp</col></row><row><col id=\"0\" trans"
  "latable=\"yes\">Window title</col></row><row><col id=\"0\" translatable"
  "=\"yes\">Group title and window title</col></row><row><col id=\"0\" tra"
  "nslatable=\"yes\">None, allow drag-and-drop</col></row></data></object>"
  "<object class=\"XfceTitledDialog\" id=\"dialog\"><property name=\"can_f"
  "ocus\">False</property><property name=\"title\" translatable=\"yes\">Wi"
  "ndow Buttons</property><property name=\"icon_name\">document-properties"
  "</property><property name=\"type_hint\">normal</property><child interna"
  "l-child=\"vbox\"><object class=\"GtkBox\" id=\"dialog-vbox2\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"orientation\">vertical</property><property name"
  "=\"spacing\">2</property><child internal-child=\"action_area\"><object "
  "class=\"GtkButtonBox\" id=\"dialog-action_area2\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"layout_style\">end</property><child><object class=\"GtkButt"
  "on\" id=\"close-button\"><property name=\"label\" translatable=\"yes\">"
  "_Close</property><property name=\"use_action_appearance\">False</proper"
  "ty><property name=\"visible\">True</property><property name=\"can_focus"
  "\">True</property><property name=\"receives_default\">True</property><p"
  "roperty name=\"image\">image2</property><property name=\"use_underline\""
  ">True</property></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">False</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkButton\" id=\""
  "help-button\"><property name=\"label\" translatable=\"yes\">_Help</prop"
  "erty><property name=\"use_action_appearance\">False</property><property"
  " name=\"visible\">True</property><property name=\"can_focus\">True</pro"
  "perty><property name=\"receives_default\">True</property><property name"
  "=\"image\">image1</property><property name=\"use_underline\">True</prop"
  "erty></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">False</property><property name=\"position\">1</proper"
  "ty><property name=\"secondary\">True</property></packing></child></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"pack_type\">end</property><prope"
  "rty name=\"position\">0</property></packing></child><child><object clas"
  "s=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"border_width"
  "\">6</property><property name=\"orientation\">vertical</property><prope"
  "rty name=\"spacing\">6</property><child><object class=\"GtkFrame\" id=\""
  "frame3\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label_xalign\">0</property><p"
  "roperty name=\"shadow_type\">none</property><child><object class=\"GtkA"
  "lignment\" id=\"alignment3\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"left_padd"
  "ing\">12</property><child><object class=\"GtkBox\" id=\"vbox3\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"border_width\">6</property><property name=\"o"
  "rientation\">vertical</property><property name=\"spacing\">6</property>"
  "<child><object class=\"GtkCheckButton\" id=\"show-labels\"><property na"
  "me=\"label\" translatable=\"yes\">Show button _labels</property><proper"
  "ty name=\"use_action_appearance\">False</property><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"receives_default\">False</property><property name=\"use_unde"
  "rline\">True</property><property name=\"draw_indicator\">True</property"
  "></object><packing><property name=\"expand\">True</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">0</property></p"
  "acking></child><child><object class=\"GtkCheckButton\" id=\"flat-button"
  "s\"><property name=\"label\" translatable=\"yes\">Show _flat buttons</p"
  "roperty><property name=\"use_action_appearance\">False</property><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">True</"
  "property><property name=\"receives_default\">False</property><property "
  "name=\"use_underline\">True</property><property name=\"draw_indicator\""
  ">True</property></object><packing><property name=\"expand\">True</prope"
  "rty><property name=\"fill\">True</property><property name=\"position\">"
  "1</property></packing></child><child><object class=\"GtkCheckButton\" i"
  "d=\"show-handle\"><property name=\"label\" translatable=\"yes\">Show _h"
  "andle</property><property name=\"use_action_appearance\">False</propert"
  "y><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"receives_default\">False</property><pr"
  "operty name=\"use_underline\">True</property><property name=\"draw_indi"
  "cator\">True</property></object><packing><property name=\"expand\">True"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">2</property></packing></child><child><object class=\"GtkBox\" id"
  "=\"hbox2\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"spacing\">12</property><chi"
  "ld><object class=\"GtkLabel\" id=\"label5\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label\" translatable=\"yes\">Sorting _order:</property><property "
  "name=\"use_underline\">True</property><property name=\"mnemonic_widget\""
  ">sort-order</property></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">0</property></packing></child><child><object class=\"GtkComboBox"
  "\" id=\"sort-order\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"model\">sort-orde"
  "r-model</property><child><object class=\"GtkCellRendererText\" id=\"cel"
  "lrenderertext1\"/><attributes><attribute name=\"text\">0</attribute></a"
  "ttributes></child></object><packing><property name=\"expand\">False</pr"
  "operty><property name=\"fill\">True</property><property name=\"position"
  "\">1</property></packing></child></object><packing><property name=\"exp"
  "and\">True</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">3</property></packing></child></object></child></objec"
  "t></child><child type=\"label\"><object class=\"GtkLabel\" id=\"label1\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"label\" translatable=\"yes\">Appearan"
  "ce</property><attributes><attribute name=\"weight\" value=\"bold\"/></a"
  "ttributes></object></child></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkFram"
  "e\" id=\"frame1\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label_xalign\">0</pr"
  "operty><property name=\"shadow_type\">none</property><child><object cla"
  "ss=\"GtkAlignment\" id=\"alignment1\"><property name=\"visible\">True</"
  "property><property name=\"can_focus\">False</property><property name=\""
  "left_padding\">12</property><child><object class=\"GtkBox\" id=\"vbox2\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"border_width\">6</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">6</p"
  "roperty><child><object class=\"GtkBox\" id=\"hbox1\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"spacing\">12</property><child><object class=\"GtkLabel\""
  " id=\"label4\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"label\" translatable=\""
  "yes\">Window _grouping:</property><property name=\"use_underline\">True"
  "</property><property name=\"mnemonic_widget\">grouping</property><prope"
  "rty name=\"xalign\">0</property></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">0</property></packing></child><child><object class=\"G"
  "tkComboBox\" id=\"grouping\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"model\">g"
  "rouping-model</property><child><object class=\"GtkCellRendererText\" id"
  "=\"cellrenderertext2\"/><attributes><attribute name=\"text\">0</attribu"
  "te></attributes></child></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">1</property></packing></child></object><packing><property name"
  "=\"expand\">True</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">0</property></packing></child><child><object cla"
  "ss=\"GtkBox\" id=\"hbox3\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"spacing\">1"
  "2</property><child><object class=\"GtkLabel\" id=\"label6\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"label\" translatable=\"yes\">Mi_ddle click action"
  ":</property><property name=\"use_underline\">True</property><property n"
  "ame=\"mnemonic_widget\">middle-click</property><property name=\"xalign\""
  ">0</property></object><packing><property name=\"expand\">False</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">0<"
  "/property></packing></child><child><object class=\"GtkComboBox\" id=\"m"
  "iddle-click\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"model\">middle-click-mod"
  "el</property><child><object class=\"GtkCellRendererText\" id=\"cellrend"
  "erertext3\"/><attributes><attribute name=\"text\">0</attribute></attrib"
  "utes></child></object><packing><property name=\"expand\">False</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">1<"
  "/property></packing></child></object><packing><property name=\"expand\""
  ">True</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child><child><object class=\"GtkChec"
  "kButton\" id=\"switch-workspace-on-unminimize\"><property name=\"label\""
  " translatable=\"yes\">Restore minimized windows to current _workspace</"
  "property><property name=\"use_action_appearance\">False</property><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">True<"
  "/property><property name=\"receives_default\">False</property><property"
  " name=\"use_underline\">True</property><property name=\"draw_indicator\""
  ">True</property></object><packing><property name=\"expand\">True</prope"
  "rty><property name=\"fill\">True</property><property name=\"position\">"
  "2</property></packing></child><child><object class=\"GtkCheckButton\" i"
  "d=\"show-wireframes\"><property name=\"label\" translatable=\"yes\">D_r"
  "aw window frame when hovering a button</property><property name=\"use_a"
  "ction_appearance\">False</property><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">True</property><property name=\"rece"
  "ives_default\">False</property><property name=\"use_underline\">True</p"
  "roperty><property name=\"draw_indicator\">True</property></object><pack"
  "ing><property name=\"expand\">True</property><property name=\"fill\">Tr"
  "ue</property><property name=\"position\">3</property></packing></child>"
  "<child><object class=\"GtkCheckButton\" id=\"window-scrolling\"><proper"
  "ty name=\"label\" translatable=\"yes\">_Switch windows using the mouse "
  "wheel</property><property name=\"use_action_appearance\">False</propert"
  "y><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"receives_default\">False</property><pr"
  "operty name=\"use_underline\">True</property><property name=\"draw_indi"
  "cator\">True</property></object><packing><property name=\"expand\">True"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">4</property></packing></child></object></child></object></child>"
  "<child type=\"label\"><object class=\"GtkLabel\" id=\"label3\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"label\" translatable=\"yes\">Behaviour</proper"
  "ty><attributes><attribute name=\"weight\" value=\"bold\"/></attributes>"
  "</object></child></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">1</property></packing></child><child><object class=\"GtkFrame\" id=\"f"
  "rame2\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"label_xalign\">0</property><pr"
  "operty name=\"shadow_type\">none</property><child><object class=\"GtkAl"
  "ignment\" id=\"alignment2\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"left_paddi"
  "ng\">12</property><child><object class=\"GtkBox\" id=\"vbox4\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"border_width\">6</property><property name=\"or"
  "ientation\">vertical</property><property name=\"spacing\">6</property><"
  "child><object class=\"GtkCheckButton\" id=\"include-all-workspaces\"><p"
  "roperty name=\"label\" translatable=\"yes\">Show windows from _all work"
  "spaces or viewports</property><property name=\"use_action_appearance\">"
  "False</property><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">True</property><property name=\"receives_default\">Fals"
  "e</property><property name=\"use_underline\">True</property><property n"
  "ame=\"draw_indicator\">True</property></object><packing><property name="
  "\"expand\">True</property><property name=\"fill\">True</property><prope"
  "rty name=\"position\">0</property></packing></child><child><object clas"
  "s=\"GtkCheckButton\" id=\"include-all-monitors\"><property name=\"label"
  "\" translatable=\"yes\">Show windows from all mo_nitors</property><prop"
  "erty name=\"use_action_appearance\">False</property><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">True</property><pro"
  "perty name=\"receives_default\">False</property><property name=\"use_un"
  "derline\">True</property><property name=\"draw_indicator\">True</proper"
  "ty></object><packing><property name=\"expand\">True</property><property"
  " name=\"fill\">True</property><property name=\"position\">1</property><"
  "/packing></child><child><object class=\"GtkCheckButton\" id=\"show-only"
  "-minimized\"><property name=\"label\" translatable=\"yes\">Show only _m"
  "inimized windows</property><property name=\"use_action_appearance\">Fal"
  "se</property><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">False</p"
  "roperty><property name=\"use_underline\">True</property><property name="
  "\"draw_indicator\">True</property></object><packing><property name=\"ex"
  "pand\">True</property><property name=\"fill\">True</property><property "
  "name=\"position\">1</property></packing></child></object></child></obje"
  "ct></child><child type=\"label\"><object class=\"GtkLabel\" id=\"label2"
  "\"><property name=\"visible\">True</property><property name=\"can_focus"
  "\">False</property><property name=\"label\" translatable=\"yes\">Filter"
  "ing</property><attributes><attribute name=\"weight\" value=\"bold\"/></"
  "attributes></object></child></object><packing><property name=\"expand\""
  ">True</property><property name=\"fill\">True</property><property name=\""
  "position\">2</property></packing></child></object><packing><property na"
  "me=\"expand\">False</property><property name=\"fill\">True</property><p"
  "roperty name=\"position\">1</property></packing></child></object></chil"
  "d><action-widgets><action-widget response=\"0\">close-button</action-wi"
  "dget><action-widget response=\"0\">help-button</action-widget></action-"
  "widgets></object><object class=\"GtkSizeGroup\" id=\"sizegroup1\"><widg"
  "ets><widget name=\"label4\"/><widget name=\"label6\"/></widgets></objec"
  "t></interface>"
};

static const unsigned tasklist_dialog_ui_length = 16528u;

