/* automatically generated from panel-preferences-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (panel_preferences_dialog_ui)
#endif
#ifdef __GNUC__
static const char panel_preferences_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char panel_preferences_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkListStore\" id=\"autohide-behavior-store\"><columns"
  "><column type=\"gchararray\"/></columns><data><row><col id=\"0\" transl"
  "atable=\"yes\">Never</col></row><row><col id=\"0\" translatable=\"yes\""
  ">Intelligently</col></row><row><col id=\"0\" translatable=\"yes\">Alway"
  "s</col></row></data></object><object class=\"GtkSizeGroup\" id=\"bg-siz"
  "egroup\"/><object class=\"GtkSizeGroup\" id=\"display-sizegroup\"/><obj"
  "ect class=\"GtkAdjustment\" id=\"enter-opacity\"><property name=\"upper"
  "\">100</property><property name=\"value\">100</property><property name="
  "\"step_increment\">1</property><property name=\"page_increment\">10</pr"
  "operty></object><object class=\"GtkAdjustment\" id=\"icon-size\"><prope"
  "rty name=\"upper\">100</property><property name=\"step_increment\">1</p"
  "roperty><property name=\"page_increment\">10</property></object><object"
  " class=\"GtkImage\" id=\"image10\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"ico"
  "n_name\">package-x-generic</property></object><object class=\"GtkImage\""
  " id=\"image11\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"icon_name\">window-clo"
  "se</property></object><object class=\"GtkImage\" id=\"image12\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"icon_name\">help-browser</property></object><"
  "object class=\"GtkAdjustment\" id=\"leave-opacity\"><property name=\"up"
  "per\">100</property><property name=\"value\">100</property><property na"
  "me=\"step_increment\">1</property><property name=\"page_increment\">10<"
  "/property></object><object class=\"GtkAdjustment\" id=\"length\"><prope"
  "rty name=\"lower\">1</property><property name=\"upper\">100</property><"
  "property name=\"value\">25</property><property name=\"step_increment\">"
  "1</property><property name=\"page_increment\">10</property></object><ob"
  "ject class=\"GtkListStore\" id=\"mode-store\"><columns><column type=\"g"
  "chararray\"/></columns><data><row><col id=\"0\" translatable=\"yes\">Ho"
  "rizontal</col></row><row><col id=\"0\" translatable=\"yes\">Vertical</c"
  "ol></row><row><col id=\"0\" translatable=\"yes\">Deskbar</col></row></d"
  "ata></object><object class=\"GtkAdjustment\" id=\"nrows\"><property nam"
  "e=\"lower\">1</property><property name=\"upper\">6</property><property "
  "name=\"value\">1</property><property name=\"step_increment\">1</propert"
  "y><property name=\"page_increment\">1</property></object><object class="
  "\"GtkListStore\" id=\"output-store\"><columns><column type=\"gchararray"
  "\"/><column type=\"gchararray\"/></columns></object><object class=\"Gtk"
  "ListStore\" id=\"panel-store\"><columns><column type=\"gint\"/><column "
  "type=\"gchararray\"/></columns></object><object class=\"GtkAdjustment\""
  " id=\"size\"><property name=\"lower\">16</property><property name=\"upp"
  "er\">128</property><property name=\"value\">16</property><property name"
  "=\"step_increment\">1</property><property name=\"page_increment\">10</p"
  "roperty></object><object class=\"GtkListStore\" id=\"styles-store\"><co"
  "lumns><column type=\"gchararray\"/></columns><data><row><col id=\"0\" t"
  "ranslatable=\"yes\">None (use system style)</col></row><row><col id=\"0"
  "\" translatable=\"yes\">Solid color</col></row><row><col id=\"0\" trans"
  "latable=\"yes\">Background image</col></row></data></object><object cla"
  "ss=\"XfceTitledDialog\" id=\"dialog\"><property name=\"can_focus\">Fals"
  "e</property><property name=\"title\" translatable=\"yes\">Panel Prefere"
  "nces</property><property name=\"window_position\">center-on-parent</pro"
  "perty><property name=\"icon_name\">xfce4-panel</property><property name"
  "=\"type_hint\">normal</property><child internal-child=\"vbox\"><object "
  "class=\"GtkBox\" id=\"dialog-vbox1\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"o"
  "rientation\">vertical</property><property name=\"spacing\">2</property>"
  "<child internal-child=\"action_area\"><object class=\"GtkButtonBox\" id"
  "=\"dialog-action_area1\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"layout_style\""
  ">end</property><child><object class=\"GtkButton\" id=\"button-close\"><"
  "property name=\"label\" translatable=\"yes\">_Close</property><property"
  " name=\"visible\">True</property><property name=\"can_focus\">True</pro"
  "perty><property name=\"receives_default\">True</property><property name"
  "=\"image\">image11</property><property name=\"use_underline\">True</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">False</property><property name=\"position\">0</prope"
  "rty></packing></child><child><object class=\"GtkButton\" id=\"button-he"
  "lp\"><property name=\"label\" translatable=\"yes\">_Help</property><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"receives_default\">True</property><property"
  " name=\"image\">image12</property><property name=\"use_underline\">True"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">False</property><property name=\"position\">1</"
  "property><property name=\"secondary\">True</property></packing></child>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">False</property><property name=\"pack_type\">end</property"
  "><property name=\"position\">0</property></packing></child><child><obje"
  "ct class=\"GtkBox\" id=\"plug-child\"><property name=\"visible\">True</"
  "property><property name=\"can_focus\">False</property><property name=\""
  "border_width\">6</property><property name=\"orientation\">vertical</pro"
  "perty><property name=\"spacing\">12</property><child><object class=\"Gt"
  "kGrid\" id=\"panel-profiles\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"row_spac"
  "ing\">6</property><property name=\"column_spacing\">12</property><child"
  "><object class=\"GtkBox\" id=\"hbox7\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "spacing\">6</property><child><object class=\"GtkLabel\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"label\" translatable=\"yes\">Profiles:</property></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"position\">0</property></packi"
  "ng></child></object><packing><property name=\"left_attach\">0</property"
  "><property name=\"top_attach\">0</property></packing></child><child><ob"
  "ject class=\"GtkSeparator\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"hexpand\">"
  "True</property></object><packing><property name=\"left_attach\">0</prop"
  "erty><property name=\"top_attach\">1</property><property name=\"width\""
  ">2</property></packing></child><child><object class=\"GtkButton\" id=\""
  "panel-switch\"><property name=\"label\" translatable=\"yes\">_Backup an"
  "d restore</property><property name=\"visible\">True</property><property"
  " name=\"can_focus\">True</property><property name=\"receives_default\">"
  "True</property><property name=\"tooltip_text\" translatable=\"yes\">Swi"
  "tch between panel presets</property><property name=\"image\">image10</p"
  "roperty><property name=\"use_underline\">True</property></object><packi"
  "ng><property name=\"left_attach\">1</property><property name=\"top_atta"
  "ch\">0</property></packing></child></object><packing><property name=\"e"
  "xpand\">False</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">0</property></packing></child><child><object class="
  "\"GtkBox\" id=\"hbox3\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"spacing\">6</p"
  "roperty><child><object class=\"GtkComboBox\" id=\"panel-combobox\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"model\">panel-store</property><child><obje"
  "ct class=\"GtkCellRendererText\" id=\"cellrenderertext2\"/><attributes>"
  "<attribute name=\"text\">1</attribute></attributes></child></object><pa"
  "cking><property name=\"expand\">True</property><property name=\"fill\">"
  "True</property><property name=\"position\">0</property></packing></chil"
  "d><child><object class=\"GtkButton\" id=\"panel-add\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">True</property><property name=\"toolt"
  "ip_text\" translatable=\"yes\">Add a new panel</property><child><object"
  " class=\"GtkImage\" id=\"image1\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"marg"
  "in_left\">3</property><property name=\"margin_right\">3</property><prop"
  "erty name=\"margin_top\">3</property><property name=\"margin_bottom\">3"
  "</property><property name=\"icon_name\">list-add</property></object></c"
  "hild></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">1</propert"
  "y></packing></child><child><object class=\"GtkButton\" id=\"panel-remov"
  "e\"><property name=\"visible\">True</property><property name=\"sensitiv"
  "e\">False</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"receives_default\">True</property><property name=\"tooltip_te"
  "xt\" translatable=\"yes\">Remove the currently selected panel</property"
  "><child><object class=\"GtkImage\" id=\"image2\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"margin_left\">3</property><property name=\"margin_right\">3<"
  "/property><property name=\"margin_top\">3</property><property name=\"ma"
  "rgin_bottom\">3</property><property name=\"icon_name\">list-remove</pro"
  "perty></object></child></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">2</property></packing></child></object><packing><property name="
  "\"expand\">False</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">1</property></packing></child><child><object cla"
  "ss=\"GtkNotebook\" id=\"notebook\"><property name=\"visible\">True</pro"
  "perty><property name=\"sensitive\">False</property><property name=\"can"
  "_focus\">True</property><child><object class=\"GtkBox\" id=\"vbox2\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"border_width\">12</property><property na"
  "me=\"orientation\">vertical</property><property name=\"spacing\">6</pro"
  "perty><child><object class=\"GtkGrid\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "margin_bottom\">18</property><property name=\"row_spacing\">6</property"
  "><property name=\"column_spacing\">12</property><child><object class=\""
  "GtkLabel\" id=\"label2\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"hexpand\">Tru"
  "e</property><property name=\"label\" translatable=\"yes\">&lt;b&gt;Gene"
  "ral&lt;/b&gt;</property><property name=\"use_markup\">True</property><p"
  "roperty name=\"xalign\">0</property></object><packing><property name=\""
  "left_attach\">0</property><property name=\"top_attach\">0</property><pr"
  "operty name=\"width\">2</property></packing></child><child><object clas"
  "s=\"GtkLabel\" id=\"label1\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"margin_le"
  "ft\">12</property><property name=\"label\" translatable=\"yes\">M_ode:<"
  "/property><property name=\"use_underline\">True</property><property nam"
  "e=\"xalign\">0</property></object><packing><property name=\"left_attach"
  "\">0</property><property name=\"top_attach\">1</property></packing></ch"
  "ild><child><object class=\"GtkComboBox\" id=\"mode\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"hexpand\">True</property><property name=\"model\">mode-s"
  "tore</property><child><object class=\"GtkCellRendererText\" id=\"cellre"
  "nderertext1\"/><attributes><attribute name=\"text\">0</attribute></attr"
  "ibutes></child></object><packing><property name=\"left_attach\">1</prop"
  "erty><property name=\"top_attach\">1</property></packing></child><child"
  "><object class=\"GtkCheckButton\" id=\"span-monitors\"><property name=\""
  "label\" translatable=\"yes\">Span mo_nitors</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">False</property><property name=\"tool"
  "tip_text\" translatable=\"yes\">Select this option to extend the panel "
  "over multiple monitors.</property><property name=\"margin_left\">12</pr"
  "operty><property name=\"use_underline\">True</property><property name=\""
  "draw_indicator\">True</property></object><packing><property name=\"left"
  "_attach\">0</property><property name=\"top_attach\">3</property><proper"
  "ty name=\"width\">2</property></packing></child><child><object class=\""
  "GtkCheckButton\" id=\"position-locked\"><property name=\"label\" transl"
  "atable=\"yes\">_Lock panel</property><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">True</property><property name=\"re"
  "ceives_default\">False</property><property name=\"tooltip_text\" transl"
  "atable=\"yes\">Select this option to hide the handles of the panel and "
  "lock its position.</property><property name=\"margin_left\">12</propert"
  "y><property name=\"use_underline\">True</property><property name=\"draw"
  "_indicator\">True</property></object><packing><property name=\"left_att"
  "ach\">0</property><property name=\"top_attach\">4</property><property n"
  "ame=\"width\">2</property></packing></child><child><object class=\"GtkC"
  "heckButton\" id=\"disable-struts\"><property name=\"label\" translatabl"
  "e=\"yes\">Don\'t _reserve space on borders</property><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">True</property><pr"
  "operty name=\"receives_default\">False</property><property name=\"toolt"
  "ip_text\" translatable=\"yes\">Select this option if you want maximized"
  " windows to cover the area behind the panel. This only works when the p"
  "anel is attached to a screen edge.</property><property name=\"margin_le"
  "ft\">12</property><property name=\"use_underline\">True</property><prop"
  "erty name=\"draw_indicator\">True</property></object><packing><property"
  " name=\"left_attach\">0</property><property name=\"top_attach\">6</prop"
  "erty><property name=\"width\">2</property></packing></child><child><obj"
  "ect class=\"GtkBox\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"spacing\">12</pro"
  "perty><child><object class=\"GtkLabel\" id=\"autohide_label\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"margin_left\">12</property><property name=\"lab"
  "el\" translatable=\"yes\">Au_tomatically hide the panel:</property><pro"
  "perty name=\"use_underline\">True</property><property name=\"xalign\">0"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"position\">0</p"
  "roperty></packing></child><child><object class=\"GtkComboBox\" id=\"aut"
  "ohide-behavior\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"model\">autohide-beha"
  "vior-store</property><child><object class=\"GtkCellRendererText\" id=\""
  "cellrenderertext5\"/><attributes><attribute name=\"text\">0</attribute>"
  "</attributes></child></object><packing><property name=\"expand\">True</"
  "property><property name=\"fill\">True</property><property name=\"pack_t"
  "ype\">end</property><property name=\"position\">1</property></packing><"
  "/child></object><packing><property name=\"left_attach\">0</property><pr"
  "operty name=\"top_attach\">5</property><property name=\"width\">2</prop"
  "erty></packing></child><child><object class=\"GtkLabel\" id=\"output-la"
  "bel\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"margin_left\">12</property><prop"
  "erty name=\"label\" translatable=\"yes\">O_utput:</property><property n"
  "ame=\"use_underline\">True</property><property name=\"xalign\">0</prope"
  "rty></object><packing><property name=\"left_attach\">0</property><prope"
  "rty name=\"top_attach\">2</property></packing></child><child><object cl"
  "ass=\"GtkComboBox\" id=\"output-name\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "model\">output-store</property><child><object class=\"GtkCellRendererTe"
  "xt\" id=\"cellrenderertext3\"/><attributes><attribute name=\"text\">1</"
  "attribute></attributes></child></object><packing><property name=\"left_"
  "attach\">1</property><property name=\"top_attach\">2</property></packin"
  "g></child></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">True</property><property name=\"position\">0</pr"
  "operty></packing></child><child><object class=\"GtkGrid\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"row_spacing\">6</property><property name=\"column_s"
  "pacing\">12</property><child><object class=\"GtkLabel\" id=\"label5\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><property name=\"label\" translatable=\"yes\" comments=\""
  "I18N: name of the section (frame) in the panel preferences where the us"
  "er can define the length and size of the panel\">&lt;b&gt;Measurements&"
  "lt;/b&gt;</property><property name=\"use_markup\">True</property><prope"
  "rty name=\"xalign\">0</property></object><packing><property name=\"left"
  "_attach\">0</property><property name=\"top_attach\">0</property><proper"
  "ty name=\"width\">2</property></packing></child><child><object class=\""
  "GtkLabel\" id=\"label3\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"margin_left\""
  ">12</property><property name=\"label\" translatable=\"yes\">Row _size ("
  "pixels):</property><property name=\"use_underline\">True</property><pro"
  "perty name=\"xalign\">0</property></object><packing><property name=\"le"
  "ft_attach\">0</property><property name=\"top_attach\">1</property></pac"
  "king></child><child><object class=\"GtkScale\" id=\"size-scale\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">True</"
  "property><property name=\"hexpand\">True</property><property name=\"adj"
  "ustment\">size</property><property name=\"digits\">0</property><propert"
  "y name=\"value_pos\">right</property></object><packing><property name=\""
  "left_attach\">1</property><property name=\"top_attach\">1</property></p"
  "acking></child><child><object class=\"GtkLabel\" id=\"label18\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"margin_left\">12</property><property name=\"l"
  "abel\" translatable=\"yes\">Num_ber of rows:</property><property name=\""
  "use_underline\">True</property><property name=\"xalign\">0</property></"
  "object><packing><property name=\"left_attach\">0</property><property na"
  "me=\"top_attach\">2</property></packing></child><child><object class=\""
  "GtkScale\" id=\"nrows-scale\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"hexpand\""
  ">True</property><property name=\"adjustment\">nrows</property><property"
  " name=\"digits\">0</property><property name=\"value_pos\">right</proper"
  "ty></object><packing><property name=\"left_attach\">1</property><proper"
  "ty name=\"top_attach\">2</property></packing></child><child><object cla"
  "ss=\"GtkLabel\" id=\"label4\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"margin_l"
  "eft\">12</property><property name=\"label\" translatable=\"yes\">L_engt"
  "h (%):</property><property name=\"use_underline\">True</property><prope"
  "rty name=\"xalign\">0</property></object><packing><property name=\"left"
  "_attach\">0</property><property name=\"top_attach\">3</property></packi"
  "ng></child><child><object class=\"GtkScale\" id=\"length-scale\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">True</"
  "property><property name=\"hexpand\">True</property><property name=\"adj"
  "ustment\">length</property><property name=\"digits\">0</property><prope"
  "rty name=\"value_pos\">right</property></object><packing><property name"
  "=\"left_attach\">1</property><property name=\"top_attach\">3</property>"
  "</packing></child><child><object class=\"GtkCheckButton\" id=\"length-a"
  "djust\"><property name=\"label\" translatable=\"yes\">A_utomatically in"
  "crease the length</property><property name=\"visible\">True</property><"
  "property name=\"can_focus\">True</property><property name=\"receives_de"
  "fault\">False</property><property name=\"tooltip_text\" translatable=\""
  "yes\">Select this option to automatically increase the length of the pa"
  "nel if the plugins request more space.</property><property name=\"margi"
  "n_left\">12</property><property name=\"use_underline\">True</property><"
  "property name=\"draw_indicator\">True</property></object><packing><prop"
  "erty name=\"left_attach\">0</property><property name=\"top_attach\">4</"
  "property><property name=\"width\">2</property></packing></child></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">True</property><property name=\"position\">2</property></packing>"
  "</child></object></child><child type=\"tab\"><object class=\"GtkLabel\""
  " id=\"label6\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"label\" translatable=\""
  "yes\">D_isplay</property><property name=\"use_underline\">True</propert"
  "y></object><packing><property name=\"tab_fill\">False</property></packi"
  "ng></child><child><object class=\"GtkBox\" id=\"vbox7\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"border_width\">12</property><property name=\"orientat"
  "ion\">vertical</property><property name=\"spacing\">6</property><child>"
  "<object class=\"GtkGrid\" id=\"background-grid\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"margin_bottom\">18</property><property name=\"row_spacing\">"
  "6</property><property name=\"column_spacing\">12</property><child><obje"
  "ct class=\"GtkLabel\" id=\"label8\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"he"
  "xpand\">True</property><property name=\"label\" translatable=\"yes\">&l"
  "t;b&gt;Background&lt;/b&gt;</property><property name=\"use_markup\">Tru"
  "e</property><property name=\"xalign\">0</property></object><packing><pr"
  "operty name=\"left_attach\">0</property><property name=\"top_attach\">0"
  "</property><property name=\"width\">2</property></packing></child><chil"
  "d><object class=\"GtkLabel\" id=\"label7\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"margin_left\">12</property><property name=\"label\" translatable=\""
  "yes\">_Style:</property><property name=\"use_underline\">True</property"
  "><property name=\"xalign\">0</property></object><packing><property name"
  "=\"left_attach\">0</property><property name=\"top_attach\">1</property>"
  "</packing></child><child><object class=\"GtkComboBox\" id=\"background-"
  "style\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"hexpand\">True</property><prop"
  "erty name=\"model\">styles-store</property><child><object class=\"GtkCe"
  "llRendererText\" id=\"cellrenderertext4\"/><attributes><attribute name="
  "\"text\">0</attribute></attributes></child></object><packing><property "
  "name=\"left_attach\">1</property><property name=\"top_attach\">1</prope"
  "rty></packing></child><child><object class=\"GtkLabel\" id=\"background"
  "-rgba-label\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"margin_left\">12</proper"
  "ty><property name=\"label\" translatable=\"yes\">C_olor:</property><pro"
  "perty name=\"use_underline\">True</property><property name=\"xalign\">0"
  "</property></object><packing><property name=\"left_attach\">0</property"
  "><property name=\"top_attach\">2</property></packing></child><child><ob"
  "ject class=\"GtkColorButton\" id=\"background-rgba\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"receives_default\">True</property><property name=\"halig"
  "n\">end</property><property name=\"title\" translatable=\"yes\">Pick a "
  "Panel Color</property><property name=\"rgba\">rgb(217,64,217)</property"
  "></object><packing><property name=\"left_attach\">1</property><property"
  " name=\"top_attach\">2</property></packing></child><child><object class"
  "=\"GtkLabel\" id=\"background-image-label\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"margin_left\">12</property><property name=\"label\" translatable="
  "\"yes\">_File:</property><property name=\"use_underline\">True</propert"
  "y><property name=\"xalign\">0</property></object><packing><property nam"
  "e=\"left_attach\">0</property><property name=\"top_attach\">3</property"
  "></packing></child><child><object class=\"GtkFileChooserButton\" id=\"b"
  "ackground-image\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"title\" translatable"
  "=\"yes\">Select A Background Image</property></object><packing><propert"
  "y name=\"left_attach\">1</property><property name=\"top_attach\">3</pro"
  "perty></packing></child></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">0</property></packing></child><child><object class=\"GtkGrid\""
  "><property name=\"name\">icons-grid</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"margin_bottom\">18</property><property name=\"row_spacing\">6</p"
  "roperty><property name=\"column_spacing\">12</property><child><object c"
  "lass=\"GtkLabel\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label\" translatable"
  "=\"yes\">&lt;b&gt;Icons&lt;/b&gt;</property><property name=\"use_markup"
  "\">True</property><property name=\"xalign\">0</property></object><packi"
  "ng><property name=\"left_attach\">0</property><property name=\"top_atta"
  "ch\">0</property></packing></child><child><object class=\"GtkLabel\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"margin_left\">12</property><property nam"
  "e=\"label\" translatable=\"yes\">Adjust size au_tomatically</property><"
  "property name=\"use_underline\">True</property><property name=\"xalign\""
  ">0</property></object><packing><property name=\"left_attach\">0</proper"
  "ty><property name=\"top_attach\">1</property></packing></child><child><"
  "object class=\"GtkSwitch\" id=\"icon-size-switch\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">True</property><prop"
  "erty name=\"halign\">end</property><property name=\"valign\">center</pr"
  "operty></object><packing><property name=\"left_attach\">1</property><pr"
  "operty name=\"top_attach\">1</property></packing></child><child><object"
  " class=\"GtkRevealer\" id=\"icon-size-revealer\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"reveal_child\">True</property><child><object class=\"GtkBox\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"hexpand\">True</property><property na"
  "me=\"spacing\">6</property><child><object class=\"GtkLabel\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"margin_left\">12</property><property name=\"labe"
  "l\" translatable=\"yes\">Fixed icon _size (pixels):</property><property"
  " name=\"use_underline\">True</property><property name=\"xalign\">0</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">0</proper"
  "ty></packing></child><child><object class=\"GtkSpinButton\" id=\"icon-s"
  "ize-spinbutton\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">True</property><property name=\"adjustment\">icon-size"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"pack_type\">end"
  "</property><property name=\"position\">1</property></packing></child></"
  "object></child></object><packing><property name=\"left_attach\">0</prop"
  "erty><property name=\"top_attach\">2</property><property name=\"width\""
  ">2</property></packing></child><child><placeholder/></child></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">1</property></packing></chi"
  "ld><child><object class=\"GtkLabel\" id=\"label11\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"label\" translatable=\"yes\">&lt;b&gt;Opacity&lt;/b&gt;</"
  "property><property name=\"use_markup\">True</property><property name=\""
  "xalign\">0</property></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">2</property></packing></child><child><object class=\"GtkRevealer\""
  " id=\"composited-info\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"reveal_child\""
  ">True</property><child><object class=\"GtkInfoBar\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><ch"
  "ild internal-child=\"action_area\"><object class=\"GtkButtonBox\"><prop"
  "erty name=\"can_focus\">False</property><property name=\"spacing\">6</p"
  "roperty><property name=\"layout_style\">end</property><child><object cl"
  "ass=\"GtkButton\" id=\"xfwm4-settings\"><property name=\"label\" transl"
  "atable=\"yes\">Configure...</property><property name=\"visible\">True</"
  "property><property name=\"can_focus\">True</property><property name=\"r"
  "eceives_default\">True</property></object><packing><property name=\"exp"
  "and\">True</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">0</property></packing></child></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">False</prop"
  "erty><property name=\"position\">0</property></packing></child><child i"
  "nternal-child=\"content_area\"><object class=\"GtkBox\"><property name="
  "\"can_focus\">False</property><property name=\"spacing\">6</property><c"
  "hild><object class=\"GtkImage\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"icon_n"
  "ame\">dialog-information-symbolic</property></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">0</property></packing></child><child><obje"
  "ct class=\"GtkLabel\" id=\"label17\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"l"
  "abel\" translatable=\"yes\">&lt;b&gt;Compositing is currently disabled&"
  "lt;/b&gt;\nEnable compositing in the window manager for opacity setting"
  "s in the panel.</property><property name=\"use_markup\">True</property>"
  "<property name=\"wrap\">True</property><property name=\"width_chars\">0"
  "</property></object><packing><property name=\"expand\">True</property><"
  "property name=\"fill\">True</property><property name=\"position\">1</pr"
  "operty></packing></child></object><packing><property name=\"expand\">Fa"
  "lse</property><property name=\"fill\">False</property><property name=\""
  "position\">0</property></packing></child></object></child></object><pac"
  "king><property name=\"expand\">False</property><property name=\"fill\">"
  "True</property><property name=\"position\">3</property></packing></chil"
  "d><child><object class=\"GtkGrid\" id=\"composited\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"margin_left\">12</property><property name=\"row_spacing\""
  ">6</property><property name=\"column_spacing\">12</property><child><obj"
  "ect class=\"GtkLabel\" id=\"label9\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"l"
  "abel\" translatable=\"yes\" comments=\"I18N: label for the enter transp"
  "arency slider\">_Enter:</property><property name=\"use_underline\">True"
  "</property><property name=\"xalign\">0</property></object><packing><pro"
  "perty name=\"left_attach\">0</property><property name=\"top_attach\">0<"
  "/property></packing></child><child><object class=\"GtkScale\" id=\"ente"
  "r-opacity-scale\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">True</property><property name=\"hexpand\">True</prope"
  "rty><property name=\"adjustment\">enter-opacity</property><property nam"
  "e=\"digits\">0</property><property name=\"value_pos\">right</property><"
  "/object><packing><property name=\"left_attach\">1</property><property n"
  "ame=\"top_attach\">0</property></packing></child><child><object class=\""
  "GtkLabel\" id=\"label10\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"label\" tran"
  "slatable=\"yes\" comments=\"I18N: label for the leave transparency slid"
  "er\">_Leave:</property><property name=\"use_underline\">True</property>"
  "<property name=\"xalign\">0</property></object><packing><property name="
  "\"left_attach\">0</property><property name=\"top_attach\">1</property><"
  "/packing></child><child><object class=\"GtkScale\" id=\"leave-opacity-s"
  "cale\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">True</property><property name=\"tooltip_text\" translatable=\"ye"
  "s\">Transparency when the pointer is not hovering over the panel, with "
  "0 being fully transparent and 100 fully opaque.</property><property nam"
  "e=\"hexpand\">True</property><property name=\"adjustment\">leave-opacit"
  "y</property><property name=\"digits\">0</property><property name=\"valu"
  "e_pos\">right</property></object><packing><property name=\"left_attach\""
  ">1</property><property name=\"top_attach\">1</property></packing></chil"
  "d></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"position\">4</property><"
  "/packing></child></object><packing><property name=\"position\">1</prope"
  "rty></packing></child><child type=\"tab\"><object class=\"GtkLabel\" id"
  "=\"label12\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"label\" translatable=\"yes"
  "\">Appeara_nce</property><property name=\"use_underline\">True</propert"
  "y></object><packing><property name=\"position\">1</property><property n"
  "ame=\"tab_fill\">False</property></packing></child><child><object class"
  "=\"GtkBox\" id=\"hbox4\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"border_width\""
  ">12</property><property name=\"spacing\">6</property><child><object cla"
  "ss=\"GtkScrolledWindow\" id=\"scrolledwindow3\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">True</property><propert"
  "y name=\"shadow_type\">etched-in</property><child><object class=\"GtkTr"
  "eeView\" id=\"item-treeview\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">True</property><property name=\"vexpand\""
  ">True</property><property name=\"headers_visible\">False</property><pro"
  "perty name=\"rules_hint\">True</property><property name=\"enable_search"
  "\">False</property><child internal-child=\"selection\"><object class=\""
  "GtkTreeSelection\"/></child></object></child></object><packing><propert"
  "y name=\"expand\">True</property><property name=\"fill\">True</property"
  "><property name=\"position\">0</property></packing></child><child><obje"
  "ct class=\"GtkBox\" id=\"vbox6\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"orien"
  "tation\">vertical</property><property name=\"spacing\">6</property><chi"
  "ld><object class=\"GtkBox\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"orientatio"
  "n\">vertical</property><child><object class=\"GtkButton\" id=\"item-up\""
  "><property name=\"visible\">True</property><property name=\"sensitive\""
  ">False</property><property name=\"can_focus\">True</property><property "
  "name=\"receives_default\">True</property><property name=\"tooltip_text\""
  " translatable=\"yes\">Move currently selected item up by one row</prope"
  "rty><child><object class=\"GtkImage\" id=\"image3\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"icon_name\">go-up</property></object></child></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkButton\" id=\"item-down\"><property name=\""
  "visible\">True</property><property name=\"sensitive\">False</property><"
  "property name=\"can_focus\">True</property><property name=\"receives_de"
  "fault\">True</property><property name=\"tooltip_text\" translatable=\"y"
  "es\">Move currently selected item down by one row</property><child><obj"
  "ect class=\"GtkImage\" id=\"image4\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"i"
  "con_name\">go-down</property></object></child></object><packing><proper"
  "ty name=\"expand\">False</property><property name=\"fill\">True</proper"
  "ty><property name=\"position\">1</property></packing></child><style><cl"
  "ass name=\"linked\"/></style></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">0</property></packing></child><child><object class=\"GtkBu"
  "tton\" id=\"item-add\"><property name=\"visible\">True</property><prope"
  "rty name=\"sensitive\">False</property><property name=\"can_focus\">Tru"
  "e</property><property name=\"receives_default\">True</property><propert"
  "y name=\"tooltip_text\" translatable=\"yes\">Add new item to this panel"
  "</property><child><object class=\"GtkImage\" id=\"image5\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"icon_name\">list-add</property></object></child></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">True</property><property name=\"position\">2</property></pac"
  "king></child><child><object class=\"GtkButton\" id=\"item-remove\"><pro"
  "perty name=\"visible\">True</property><property name=\"sensitive\">Fals"
  "e</property><property name=\"can_focus\">True</property><property name="
  "\"receives_default\">True</property><property name=\"tooltip_text\" tra"
  "nslatable=\"yes\">Remove currently selected item</property><child><obje"
  "ct class=\"GtkImage\" id=\"image6\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"ic"
  "on_name\">list-remove</property></object></child></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">True</pro"
  "perty><property name=\"position\">3</property></packing></child><child>"
  "<object class=\"GtkButton\" id=\"item-properties\"><property name=\"vis"
  "ible\">True</property><property name=\"sensitive\">False</property><pro"
  "perty name=\"can_focus\">True</property><property name=\"receives_defau"
  "lt\">True</property><property name=\"tooltip_text\" translatable=\"yes\""
  ">Edit the currently selected item</property><child><object class=\"GtkI"
  "mage\" id=\"image7\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"icon_name\">docum"
  "ent-properties</property></object></child></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">True</property><"
  "property name=\"position\">4</property></packing></child><child><object"
  " class=\"GtkButton\" id=\"item-about\"><property name=\"visible\">True<"
  "/property><property name=\"sensitive\">False</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">True</pr"
  "operty><property name=\"tooltip_text\" translatable=\"yes\">Show about "
  "information of the currently selected item</property><child><object cla"
  "ss=\"GtkImage\" id=\"image8\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"icon_nam"
  "e\">help-about</property></object></child></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">True</property><"
  "property name=\"position\">5</property></packing></child></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">1</property></packing></child"
  "></object><packing><property name=\"position\">2</property></packing></"
  "child><child type=\"tab\"><object class=\"GtkLabel\" id=\"label14\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"label\" translatable=\"yes\">Ite_ms</prop"
  "erty><property name=\"use_underline\">True</property></object><packing>"
  "<property name=\"position\">2</property><property name=\"tab_fill\">Fal"
  "se</property></packing></child></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">True</property><property na"
  "me=\"position\">2</property></packing></child></object><packing><proper"
  "ty name=\"expand\">False</property><property name=\"fill\">True</proper"
  "ty><property name=\"position\">1</property></packing></child></object><"
  "/child><action-widgets><action-widget response=\"0\">button-close</acti"
  "on-widget><action-widget response=\"1\">button-help</action-widget></ac"
  "tion-widgets></object></interface>"
};

static const unsigned panel_preferences_dialog_ui_length = 39664u;

