/* automatically generated from clock-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (clock_dialog_ui)
#endif
#ifdef __GNUC__
static const char clock_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char clock_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkAdjustment\" id=\"fuzziness\"><property name=\"uppe"
  "r\">3</property><property name=\"step_increment\">1</property><property"
  " name=\"page_increment\">1</property><property name=\"page_size\">1</pr"
  "operty></object><object class=\"GtkImage\" id=\"image1\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y><property name=\"icon_name\">time-admin</property></object><object cl"
  "ass=\"GtkImage\" id=\"image2\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"icon_na"
  "me\">window-close</property></object><object class=\"GtkImage\" id=\"im"
  "age3\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"icon_name\">help-browser</prope"
  "rty></object><object class=\"GtkListStore\" id=\"mode-model\"><columns>"
  "<column type=\"gchararray\"/></columns><data><row><col id=\"0\" transla"
  "table=\"yes\">Analog</col></row><row><col id=\"0\" translatable=\"yes\""
  ">Binary</col></row><row><col id=\"0\" translatable=\"yes\">Digital</col"
  "></row><row><col id=\"0\" translatable=\"yes\">Fuzzy</col></row><row><c"
  "ol id=\"0\" translatable=\"yes\">LCD</col></row></data></object><object"
  " class=\"XfceTitledDialog\" id=\"dialog\"><property name=\"can_focus\">"
  "False</property><property name=\"title\" translatable=\"yes\">Clock</pr"
  "operty><property name=\"icon_name\">document-properties</property><prop"
  "erty name=\"type_hint\">normal</property><child internal-child=\"vbox\""
  "><object class=\"GtkBox\" id=\"dialog-vbox2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">2</p"
  "roperty><child internal-child=\"action_area\"><object class=\"GtkButton"
  "Box\" id=\"dialog-action_area2\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"layou"
  "t_style\">end</property><child><object class=\"GtkButton\" id=\"close-b"
  "utton\"><property name=\"label\" translatable=\"yes\">_Close</property>"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "True</property><property name=\"receives_default\">True</property><prop"
  "erty name=\"image\">image2</property><property name=\"use_underline\">T"
  "rue</property></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">False</property><property name=\"position\">"
  "0</property></packing></child><child><object class=\"GtkButton\" id=\"h"
  "elp-button\"><property name=\"label\" translatable=\"yes\">_Help</prope"
  "rty><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"receives_default\">True</property><"
  "property name=\"image\">image3</property><property name=\"use_underline"
  "\">True</property></object><packing><property name=\"expand\">False</pr"
  "operty><property name=\"fill\">False</property><property name=\"positio"
  "n\">1</property><property name=\"secondary\">True</property></packing><"
  "/child></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">True</property><property name=\"pack_type\">end</pr"
  "operty><property name=\"position\">0</property></packing></child><child"
  "><object class=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "border_width\">6</property><property name=\"orientation\">vertical</pro"
  "perty><property name=\"spacing\">6</property><child><object class=\"Gtk"
  "Frame\" id=\"frame2\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"margin_bottom\">"
  "18</property><property name=\"label_xalign\">0</property><property name"
  "=\"shadow_type\">none</property><child><object class=\"GtkGrid\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"margin_left\">18</property><property name=\""
  "row_spacing\">6</property><property name=\"column_spacing\">12</propert"
  "y><child><object class=\"GtkEntry\" id=\"timezone-name\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"hexpand\">True</property><property name=\"invisible_c"
  "har\">\342\227\217</property><property name=\"secondary_icon_name\">hel"
  "p-contents</property><property name=\"primary_icon_activatable\">False<"
  "/property><property name=\"secondary_icon_tooltip_text\" translatable=\""
  "yes\">Name of a timezone corresponding a file in the zoneinfo database,"
  " for example \"America/New_York\". Leave empty to use the localtime.</p"
  "roperty></object><packing><property name=\"left_attach\">1</property><p"
  "roperty name=\"top_attach\">0</property></packing></child><child><objec"
  "t class=\"GtkLabel\" id=\"label9\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"lab"
  "el\" translatable=\"yes\">Time_zone:</property><property name=\"use_und"
  "erline\">True</property><property name=\"xalign\">0</property></object>"
  "<packing><property name=\"left_attach\">0</property><property name=\"to"
  "p_attach\">0</property></packing></child><child><object class=\"GtkButt"
  "on\" id=\"run-time-config-tool\"><property name=\"label\" translatable="
  "\"yes\">Time and Date _Settings...</property><property name=\"use_actio"
  "n_appearance\">False</property><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">True</property><property name=\"receives"
  "_default\">True</property><property name=\"image\">image1</property><pr"
  "operty name=\"use_underline\">True</property></object><packing><propert"
  "y name=\"left_attach\">0</property><property name=\"top_attach\">1</pro"
  "perty></packing></child><child><placeholder/></child></object></child><"
  "child type=\"label\"><object class=\"GtkLabel\" id=\"label6\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"margin_bottom\">6</property><property name=\"la"
  "bel\" translatable=\"yes\">Time Settings</property><attributes><attribu"
  "te name=\"weight\" value=\"bold\"/></attributes></object></child></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">0</property></packing"
  "></child><child><object class=\"GtkFrame\" id=\"frame3\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y><property name=\"margin_bottom\">18</property><property name=\"label_"
  "xalign\">0</property><property name=\"shadow_type\">none</property><chi"
  "ld><object class=\"GtkGrid\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"margin_le"
  "ft\">18</property><property name=\"row_spacing\">6</property><property "
  "name=\"column_spacing\">12</property><child><object class=\"GtkEntry\" "
  "id=\"tooltip-format\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property><property name=\"hexpand\">True</p"
  "roperty><property name=\"secondary_icon_name\">help-contents</property>"
  "<property name=\"primary_icon_activatable\">False</property><property n"
  "ame=\"secondary_icon_tooltip_text\" translatable=\"yes\">The format des"
  "cribes the date and time parts to insert into the panel. For example, %"
  "Y will be substituted with the year, %m with the month and %d with the "
  "day. Similarly, &lt;b&gt;&lt;/b&gt; tags will make the text bold. See t"
  "he \"Help\" page for additional information.</property></object><packin"
  "g><property name=\"left_attach\">0</property><property name=\"top_attac"
  "h\">2</property><property name=\"width\">2</property></packing></child>"
  "<child><object class=\"GtkComboBox\" id=\"tooltip-chooser\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"hexpand\">False</property><child><object class=\""
  "GtkCellRendererText\" id=\"cellrenderertext2\"/><attributes><attribute "
  "name=\"text\">2</attribute></attributes></child></object><packing><prop"
  "erty name=\"left_attach\">1</property><property name=\"top_attach\">1</"
  "property></packing></child><child><object class=\"GtkComboBox\" id=\"mo"
  "de\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"hexpand\">True</property><propert"
  "y name=\"model\">mode-model</property><child><object class=\"GtkCellRen"
  "dererText\" id=\"cellrenderertext1\"/><attributes><attribute name=\"tex"
  "t\">0</attribute></attributes></child></object><packing><property name="
  "\"left_attach\">1</property><property name=\"top_attach\">0</property><"
  "/packing></child><child><object class=\"GtkLabel\" id=\"label4\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"label\" translatable=\"yes\">_Tooltip format"
  ":</property><property name=\"use_underline\">True</property><property n"
  "ame=\"xalign\">0</property></object><packing><property name=\"left_atta"
  "ch\">0</property><property name=\"top_attach\">1</property></packing></"
  "child><child><object class=\"GtkLabel\" id=\"label2\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"label\" translatable=\"yes\">_Layout:</property><proper"
  "ty name=\"use_underline\">True</property><property name=\"xalign\">0</p"
  "roperty></object><packing><property name=\"left_attach\">0</property><p"
  "roperty name=\"top_attach\">0</property></packing></child></object></ch"
  "ild><child type=\"label\"><object class=\"GtkLabel\" id=\"label1\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"margin_bottom\">6</property><property name"
  "=\"label\" translatable=\"yes\">Appearance</property><attributes><attri"
  "bute name=\"weight\" value=\"bold\"/></attributes></object></child></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"position\">1</property></packi"
  "ng></child><child><object class=\"GtkFrame\" id=\"frame1\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"label_xalign\">0</property><property name=\"shadow"
  "_type\">none</property><child><object class=\"GtkGrid\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"margin_left\">18</property><property name=\"hexpand\""
  ">True</property><property name=\"row_spacing\">6</property><property na"
  "me=\"column_spacing\">12</property><child><object class=\"GtkCheckButto"
  "n\" id=\"show-meridiem\"><property name=\"label\" translatable=\"yes\">"
  "Sho_w AM/PM</property><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property><property name=\"receives_default\""
  ">False</property><property name=\"use_underline\">True</property><prope"
  "rty name=\"draw_indicator\">True</property></object><packing><property "
  "name=\"left_attach\">0</property><property name=\"top_attach\">4</prope"
  "rty><property name=\"width\">2</property></packing></child><child><obje"
  "ct class=\"GtkCheckButton\" id=\"flash-separators\"><property name=\"la"
  "bel\" translatable=\"yes\">Fl_ash time separators</property><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">True</prope"
  "rty><property name=\"receives_default\">False</property><property name="
  "\"use_underline\">True</property><property name=\"draw_indicator\">True"
  "</property></object><packing><property name=\"left_attach\">0</property"
  "><property name=\"top_attach\">3</property><property name=\"width\">2</"
  "property></packing></child><child><object class=\"GtkCheckButton\" id=\""
  "show-military\"><property name=\"label\" translatable=\"yes\">24-_hour "
  "clock</property><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">True</property><property name=\"receives_default\">Fals"
  "e</property><property name=\"use_underline\">True</property><property n"
  "ame=\"draw_indicator\">True</property></object><packing><property name="
  "\"left_attach\">0</property><property name=\"top_attach\">2</property><"
  "property name=\"width\">2</property></packing></child><child><object cl"
  "ass=\"GtkCheckButton\" id=\"true-binary\"><property name=\"label\" tran"
  "slatable=\"yes\">True _binary clock</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">False</property><property name=\"use_underline"
  "\">True</property><property name=\"draw_indicator\">True</property></ob"
  "ject><packing><property name=\"left_attach\">0</property><property name"
  "=\"top_attach\">1</property><property name=\"width\">2</property></pack"
  "ing></child><child><object class=\"GtkCheckButton\" id=\"show-seconds\""
  "><property name=\"label\" translatable=\"yes\">Display _seconds</proper"
  "ty><property name=\"visible\">True</property><property name=\"can_focus"
  "\">True</property><property name=\"receives_default\">False</property><"
  "property name=\"use_underline\">True</property><property name=\"draw_in"
  "dicator\">True</property></object><packing><property name=\"left_attach"
  "\">0</property><property name=\"top_attach\">0</property><property name"
  "=\"width\">2</property></packing></child><child><object class=\"GtkGrid"
  "\" id=\"digital-box\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"hexpand\">True</"
  "property><property name=\"row_spacing\">6</property><property name=\"co"
  "lumn_spacing\">12</property><child><object class=\"GtkComboBox\" id=\"d"
  "igital-chooser\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"hexpand\">True</prope"
  "rty><child><object class=\"GtkCellRendererText\" id=\"cellrenderertext3"
  "\"/><attributes><attribute name=\"text\">2</attribute></attributes></ch"
  "ild></object><packing><property name=\"left_attach\">1</property><prope"
  "rty name=\"top_attach\">0</property></packing></child><child><object cl"
  "ass=\"GtkLabel\" id=\"label8\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"label\""
  " translatable=\"yes\">F_ormat:</property><property name=\"use_underline"
  "\">True</property><property name=\"xalign\">0</property></object><packi"
  "ng><property name=\"left_attach\">0</property><property name=\"top_atta"
  "ch\">0</property></packing></child><child><object class=\"GtkEntry\" id"
  "=\"digital-format\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">True</property><property name=\"hexpand\">True</pro"
  "perty><property name=\"secondary_icon_name\">help-contents</property><p"
  "roperty name=\"primary_icon_activatable\">False</property><property nam"
  "e=\"secondary_icon_tooltip_text\" translatable=\"yes\">The format descr"
  "ibes the date and time parts to insert into the panel. For example, %Y "
  "will be substituted with the year, %m with the month and %d with the da"
  "y. Similarly, &lt;b&gt;&lt;/b&gt; tags will make the text bold. See the"
  " \"Help\" page for additional information.</property></object><packing>"
  "<property name=\"left_attach\">0</property><property name=\"top_attach\""
  ">1</property><property name=\"width\">2</property></packing></child></o"
  "bject><packing><property name=\"left_attach\">0</property><property nam"
  "e=\"top_attach\">5</property><property name=\"width\">2</property></pac"
  "king></child><child><object class=\"GtkBox\" id=\"fuzziness-box\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><child><object class=\"GtkLabel\" id=\"label5\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"label\" translatable=\"yes\" comments=\"I18N: the "
  "fuzziness the *precision* of the fuzzy clock. Time steps of 5, 15 or pa"
  "rts of the day.\">F_uzziness:</property><property name=\"use_underline\""
  ">True</property><property name=\"xalign\">0</property></object><packing"
  "><property name=\"expand\">False</property><property name=\"fill\">True"
  "</property><property name=\"position\">0</property></packing></child><c"
  "hild><object class=\"GtkScale\" id=\"hscale1\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">True</property><property"
  " name=\"hexpand\">True</property><property name=\"adjustment\">fuzzines"
  "s</property><property name=\"digits\">0</property><property name=\"valu"
  "e_pos\">right</property></object><packing><property name=\"expand\">Tru"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">1</property></packing></child></object><packing><property name="
  "\"left_attach\">0</property><property name=\"top_attach\">6</property><"
  "property name=\"width\">2</property></packing></child><child><object cl"
  "ass=\"GtkCheckButton\" id=\"show-inactive\"><property name=\"label\" tr"
  "anslatable=\"yes\">Show _inactive dots</property><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"receives_default\">False</property><property name=\"use_under"
  "line\">True</property><property name=\"draw_indicator\">True</property>"
  "</object><packing><property name=\"left_attach\">0</property><property "
  "name=\"top_attach\">7</property><property name=\"width\">2</property></"
  "packing></child><child><object class=\"GtkCheckButton\" id=\"show-grid\""
  "><property name=\"label\" translatable=\"yes\">Show gri_d</property><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Tru"
  "e</property><property name=\"receives_default\">False</property><proper"
  "ty name=\"use_underline\">True</property><property name=\"draw_indicato"
  "r\">True</property></object><packing><property name=\"left_attach\">0</"
  "property><property name=\"top_attach\">8</property><property name=\"wid"
  "th\">2</property></packing></child></object></child><child type=\"label"
  "\"><object class=\"GtkLabel\" id=\"label3\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"margin_bottom\">6</property><property name=\"label\" translatable"
  "=\"yes\">Clock Options</property><attributes><attribute name=\"weight\""
  " value=\"bold\"/></attributes></object></child></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">2</property></packing></child></object>"
  "<packing><property name=\"expand\">True</property><property name=\"fill"
  "\">True</property><property name=\"position\">1</property></packing></c"
  "hild></object></child><action-widgets><action-widget response=\"0\">clo"
  "se-button</action-widget><action-widget response=\"0\">help-button</act"
  "ion-widget></action-widgets></object></interface>"
};

static const unsigned clock_dialog_ui_length = 17588u;

