/* automatically generated from actions-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (actions_dialog_ui)
#endif
#ifdef __GNUC__
static const char actions_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char actions_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">window-close</property></object><object class=\"GtkImag"
  "e\" id=\"image2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">help-bro"
  "wser</property></object><object class=\"GtkListStore\" id=\"items-store"
  "\"><columns><column type=\"gboolean\"/><column type=\"gchararray\"/><co"
  "lumn type=\"gchararray\"/><column type=\"guint\"/></columns></object><o"
  "bject class=\"GtkListStore\" id=\"mode-store\"><columns><column type=\""
  "gchararray\"/></columns><data><row><col id=\"0\" translatable=\"yes\">A"
  "ction Buttons</col></row><row><col id=\"0\" translatable=\"yes\">Sessio"
  "n Menu</col></row></data></object><object class=\"XfceTitledDialog\" id"
  "=\"dialog\"><property name=\"can_focus\">False</property><property name"
  "=\"title\" translatable=\"yes\">Action Buttons</property><property name"
  "=\"default_width\">300</property><property name=\"default_height\">450<"
  "/property><property name=\"icon_name\">document-properties</property><p"
  "roperty name=\"type_hint\">normal</property><child internal-child=\"vbo"
  "x\"><object class=\"GtkBox\" id=\"dialog-vbox1\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"orientation\">vertical</property><property name=\"spacing\">"
  "2</property><child internal-child=\"action_area\"><object class=\"GtkBu"
  "ttonBox\" id=\"dialog-action_area1\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><property name=\"l"
  "ayout_style\">end</property><child><object class=\"GtkButton\" id=\"clo"
  "se-button\"><property name=\"label\" translatable=\"yes\">_Close</prope"
  "rty><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"receives_default\">True</property><"
  "property name=\"image\">image1</property><property name=\"use_underline"
  "\">True</property></object><packing><property name=\"expand\">False</pr"
  "operty><property name=\"fill\">False</property><property name=\"positio"
  "n\">0</property></packing></child><child><object class=\"GtkButton\" id"
  "=\"help-button\"><property name=\"label\" translatable=\"yes\">_Help</p"
  "roperty><property name=\"visible\">True</property><property name=\"can_"
  "focus\">True</property><property name=\"receives_default\">True</proper"
  "ty><property name=\"image\">image2</property><property name=\"use_under"
  "line\">True</property></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">False</property><property name=\"pos"
  "ition\">1</property><property name=\"secondary\">True</property></packi"
  "ng></child></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"pack_type\">end"
  "</property><property name=\"position\">0</property></packing></child><c"
  "hild><object class=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"border_width\">6</property><property name=\"orientation\">vertical"
  "</property><property name=\"spacing\">6</property><child><object class="
  "\"GtkFrame\" id=\"frame1\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"label_xalig"
  "n\">0</property><property name=\"shadow_type\">none</property><child><o"
  "bject class=\"GtkGrid\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"margin_left\">"
  "18</property><property name=\"row_spacing\">6</property><property name="
  "\"column_spacing\">12</property><child><object class=\"GtkComboBox\" id"
  "=\"combo-mode\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"hexpand\">True</proper"
  "ty><property name=\"model\">mode-store</property><child><object class=\""
  "GtkCellRendererText\" id=\"cellrenderertext2\"/><attributes><attribute "
  "name=\"text\">0</attribute></attributes></child></object><packing><prop"
  "erty name=\"left_attach\">1</property><property name=\"top_attach\">0</"
  "property></packing></child><child><object class=\"GtkCheckButton\" id=\""
  "invert-orientation\"><property name=\"label\" translatable=\"yes\">Inve"
  "rt buttons _orientation</property><property name=\"use_action_appearanc"
  "e\">False</property><property name=\"visible\">True</property><property"
  " name=\"can_focus\">True</property><property name=\"receives_default\">"
  "False</property><property name=\"use_underline\">True</property><proper"
  "ty name=\"draw_indicator\">True</property></object><packing><property n"
  "ame=\"left_attach\">0</property><property name=\"top_attach\">1</proper"
  "ty><property name=\"width\">2</property></packing></child><child><objec"
  "t class=\"GtkCheckButton\" id=\"confirmation-dialog\"><property name=\""
  "label\" translatable=\"yes\">_Show confirmation dialog</property><prope"
  "rty name=\"use_action_appearance\">False</property><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">True</property><prop"
  "erty name=\"receives_default\">False</property><property name=\"tooltip"
  "_text\" translatable=\"yes\">Show a confirmation dialog with a 30 secon"
  "d timeout for some of the actions.</property><property name=\"use_under"
  "line\">True</property><property name=\"draw_indicator\">True</property>"
  "</object><packing><property name=\"left_attach\">0</property><property "
  "name=\"top_attach\">2</property><property name=\"width\">2</property></"
  "packing></child><child><object class=\"GtkLabel\" id=\"label3\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"label\" translatable=\"yes\">Appeara_nce:</pr"
  "operty><property name=\"use_underline\">True</property><property name=\""
  "xalign\">0</property></object><packing><property name=\"left_attach\">0"
  "</property><property name=\"top_attach\">0</property></packing></child>"
  "</object></child><child type=\"label\"><object class=\"GtkLabel\" id=\""
  "label1\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "General</property><attributes><attribute name=\"weight\" value=\"bold\""
  "/></attributes></object></child></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">0</property></packing></child><child><object class=\"G"
  "tkFrame\" id=\"frame2\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"label_xalign\""
  ">0</property><property name=\"shadow_type\">none</property><child><obje"
  "ct class=\"GtkAlignment\" id=\"alignment2\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"left_padding\">12</property><child><object class=\"GtkScrolledWin"
  "dow\" id=\"scrolledwindow1\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"border_wid"
  "th\">6</property><property name=\"shadow_type\">etched-in</property><ch"
  "ild><object class=\"GtkTreeView\" id=\"actions-treeview\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">True</propert"
  "y><property name=\"model\">items-store</property><property name=\"heade"
  "rs_clickable\">False</property><property name=\"reorderable\">True</pro"
  "perty><property name=\"search_column\">0</property><child internal-chil"
  "d=\"selection\"><object class=\"GtkTreeSelection\"/></child><child><obj"
  "ect class=\"GtkTreeViewColumn\" id=\"treeviewcolumn1\"><property name=\""
  "title\" translatable=\"yes\">Visible</property><child><object class=\"G"
  "tkCellRendererToggle\" id=\"visible-toggle\"/><attributes><attribute na"
  "me=\"active\">0</attribute></attributes></child></object></child><child"
  "><object class=\"GtkTreeViewColumn\" id=\"treeviewcolumn2\"><property n"
  "ame=\"title\" translatable=\"yes\">Action</property><child><object clas"
  "s=\"GtkCellRendererText\" id=\"text-renderer\"/><attributes><attribute "
  "name=\"markup\">1</attribute></attributes></child></object></child></ob"
  "ject></child></object></child></object></child><child type=\"label\"><o"
  "bject class=\"GtkLabel\" id=\"label2\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "label\" translatable=\"yes\">_Actions</property><property name=\"use_un"
  "derline\">True</property><property name=\"mnemonic_widget\">actions-tre"
  "eview</property><attributes><attribute name=\"weight\" value=\"bold\"/>"
  "</attributes></object></child></object><packing><property name=\"expand"
  "\">True</property><property name=\"fill\">True</property><property name"
  "=\"position\">1</property></packing></child></object><packing><property"
  " name=\"expand\">True</property><property name=\"fill\">True</property>"
  "<property name=\"position\">1</property></packing></child></object></ch"
  "ild><action-widgets><action-widget response=\"0\">close-button</action-"
  "widget><action-widget response=\"0\">help-button</action-widget></actio"
  "n-widgets></object></interface>"
};

static const unsigned actions_dialog_ui_length = 8684u;

