/* automatically generated from systray-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (systray_dialog_ui)
#endif
#ifdef __GNUC__
static const char systray_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char systray_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkListStore\" id=\"applications-store\"><columns><col"
  "umn type=\"GdkPixbuf\"/><column type=\"gchararray\"/><column type=\"gbo"
  "olean\"/><column type=\"gchararray\"/></columns></object><object class="
  "\"GtkImage\" id=\"image1\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"icon_name\""
  ">edit-clear</property></object><object class=\"GtkImage\" id=\"image4\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"icon_name\">help-browser</property></"
  "object><object class=\"GtkImage\" id=\"image5\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"icon_name\">window-close</property></object><object class=\"G"
  "tkAdjustment\" id=\"size-adjustment\"><property name=\"lower\">12</prop"
  "erty><property name=\"upper\">64</property><property name=\"value\">32<"
  "/property><property name=\"step_increment\">1</property><property name="
  "\"page_increment\">2</property></object><object class=\"XfceTitledDialo"
  "g\" id=\"dialog\"><property name=\"can_focus\">False</property><propert"
  "y name=\"title\" translatable=\"yes\">Notification Area</property><prop"
  "erty name=\"default_width\">400</property><property name=\"default_heig"
  "ht\">500</property><property name=\"icon_name\">document-properties</pr"
  "operty><property name=\"type_hint\">normal</property><child internal-ch"
  "ild=\"vbox\"><object class=\"GtkBox\" id=\"dialog-vbox2\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"orientation\">vertical</property><property name=\"s"
  "pacing\">2</property><child internal-child=\"action_area\"><object clas"
  "s=\"GtkButtonBox\" id=\"dialog-action_area2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"layout_style\">end</property><child><object class=\"GtkButton\" "
  "id=\"close-button\"><property name=\"label\" translatable=\"yes\">_Clos"
  "e</property><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">True</pr"
  "operty><property name=\"image\">image5</property><property name=\"use_u"
  "nderline\">True</property></object><packing><property name=\"expand\">F"
  "alse</property><property name=\"fill\">False</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkButt"
  "on\" id=\"help-button\"><property name=\"label\" translatable=\"yes\">_"
  "Help</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">True<"
  "/property><property name=\"image\">image4</property><property name=\"us"
  "e_underline\">True</property></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">False</property><property name"
  "=\"position\">1</property><property name=\"secondary\">True</property><"
  "/packing></child></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">False</property><property name=\"pack_typ"
  "e\">end</property><property name=\"position\">0</property></packing></c"
  "hild><child><object class=\"GtkBox\" id=\"vbox1\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"border_width\">6</property><property name=\"orientation\">v"
  "ertical</property><property name=\"spacing\">6</property><child><object"
  " class=\"GtkFrame\" id=\"frame3\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"labe"
  "l_xalign\">0</property><property name=\"shadow_type\">none</property><c"
  "hild><object class=\"GtkAlignment\" id=\"alignment3\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"left_padding\">12</property><child><object class=\"GtkB"
  "ox\" id=\"vbox2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"border_width\">6</pr"
  "operty><property name=\"orientation\">vertical</property><property name"
  "=\"spacing\">6</property><child><object class=\"GtkBox\" id=\"hbox1\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><property name=\"spacing\">12</property><child><object c"
  "lass=\"GtkLabel\" id=\"label2\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"label\""
  " translatable=\"yes\">_Maximum icon size (px):</property><property name"
  "=\"use_underline\">True</property><property name=\"mnemonic_widget\">si"
  "ze-max</property><property name=\"xalign\">0</property></object><packin"
  "g><property name=\"expand\">False</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">0</property></packing></child><"
  "child><object class=\"GtkSpinButton\" id=\"size-max\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"adjustment\">size-adjustment</property><property name=\""
  "numeric\">True</property></object><packing><property name=\"expand\">Fa"
  "lse</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">1</property></packing></child></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">0</property></packing></child><child><object c"
  "lass=\"GtkCheckButton\" id=\"square-icons\"><property name=\"label\" tr"
  "anslatable=\"yes\">Sq_uare icons</property><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">True</property><property nam"
  "e=\"receives_default\">False</property><property name=\"use_underline\""
  ">True</property><property name=\"draw_indicator\">True</property></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">1</property></packing"
  "></child><child><object class=\"GtkCheckButton\" id=\"show-frame\"><pro"
  "perty name=\"label\" translatable=\"yes\">Show _frame</property><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"receives_default\">False</property><property n"
  "ame=\"use_underline\">True</property><property name=\"draw_indicator\">"
  "True</property></object><packing><property name=\"expand\">False</prope"
  "rty><property name=\"fill\">True</property><property name=\"position\">"
  "2</property></packing></child></object></child></object></child><child "
  "type=\"label\"><object class=\"GtkLabel\" id=\"label1\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"label\" translatable=\"yes\">Appearance</property><at"
  "tributes><attribute name=\"weight\" value=\"bold\"/></attributes></obje"
  "ct></child></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"position\">0</p"
  "roperty></packing></child><child><object class=\"GtkFrame\" id=\"frame1"
  "\"><property name=\"visible\">True</property><property name=\"can_focus"
  "\">False</property><property name=\"label_xalign\">0</property><propert"
  "y name=\"shadow_type\">none</property><child><object class=\"GtkAlignme"
  "nt\" id=\"alignment1\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"left_padding\">"
  "12</property><child><object class=\"GtkBox\" id=\"vbox3\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"border_width\">6</property><property name=\"orienta"
  "tion\">vertical</property><property name=\"spacing\">6</property><child"
  "><object class=\"GtkBox\" id=\"hbox2\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "border_width\">6</property><property name=\"spacing\">6</property><chil"
  "d><object class=\"GtkScrolledWindow\" id=\"scrolledwindow1\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">True</prop"
  "erty><property name=\"vexpand\">True</property><property name=\"shadow_"
  "type\">in</property><child><object class=\"GtkTreeView\" id=\"applicati"
  "ons-treeview\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"model\">applications-sto"
  "re</property><property name=\"headers_clickable\">False</property><prop"
  "erty name=\"rules_hint\">True</property><property name=\"enable_search\""
  ">False</property><child internal-child=\"selection\"><object class=\"Gt"
  "kTreeSelection\"/></child><child><object class=\"GtkTreeViewColumn\" id"
  "=\"treeviewcolumn1\"><property name=\"min_width\">24</property><child><"
  "object class=\"GtkCellRendererPixbuf\" id=\"cellrendererpixbuf1\"/><att"
  "ributes><attribute name=\"pixbuf\">0</attribute></attributes></child></"
  "object></child><child><object class=\"GtkTreeViewColumn\" id=\"treeview"
  "column2\"><property name=\"title\">Application</property><property name"
  "=\"expand\">True</property><child><object class=\"GtkCellRendererText\""
  " id=\"cellrenderertext1\"/><attributes><attribute name=\"text\">1</attr"
  "ibute></attributes></child></object></child><child><object class=\"GtkT"
  "reeViewColumn\" id=\"treeviewcolumn3\"><property name=\"title\">Hidden<"
  "/property><child><object class=\"GtkCellRendererToggle\" id=\"hidden-to"
  "ggle\"/><attributes><attribute name=\"active\">2</attribute></attribute"
  "s></child></object></child></object></child></object><packing><property"
  " name=\"expand\">True</property><property name=\"fill\">True</property>"
  "<property name=\"position\">0</property></packing></child><child><objec"
  "t class=\"GtkBox\" id=\"vbox4\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"orient"
  "ation\">vertical</property><child><object class=\"GtkButton\" id=\"item"
  "-up\"><property name=\"visible\">True</property><property name=\"sensit"
  "ive\">False</property><property name=\"can_focus\">True</property><prop"
  "erty name=\"receives_default\">True</property><property name=\"tooltip_"
  "text\" translatable=\"yes\">Move currently selected item up by one row<"
  "/property><child><object class=\"GtkImage\" id=\"image2\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"icon_name\">go-up</property></object></child></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">0</property></packing"
  "></child><child><object class=\"GtkButton\" id=\"item-down\"><property "
  "name=\"visible\">True</property><property name=\"sensitive\">False</pro"
  "perty><property name=\"can_focus\">True</property><property name=\"rece"
  "ives_default\">True</property><property name=\"tooltip_text\" translata"
  "ble=\"yes\">Move currently selected item down by one row</property><chi"
  "ld><object class=\"GtkImage\" id=\"image3\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"icon_name\">go-down</property></object></child></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">1</property></packing></child><st"
  "yle><class name=\"linked\"/></style></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">1</property></packing></child></object><packing><p"
  "roperty name=\"expand\">False</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">1</property></packing></child><chil"
  "d><object class=\"GtkButtonBox\" id=\"hbuttonbox1\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"layout_style\">start</property><child><object class=\"Gtk"
  "Button\" id=\"applications-clear\"><property name=\"label\" translatabl"
  "e=\"yes\">C_lear Known Applications</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">True</property><property name=\"image\">image1"
  "</property><property name=\"use_underline\">True</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">False</property><property name=\"position\">0</property></packing></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"position\">1</property"
  "></packing></child></object></child></object></child><child type=\"labe"
  "l\"><object class=\"GtkLabel\" id=\"label3\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">Known Applications</property><attri"
  "butes><attribute name=\"weight\" value=\"bold\"/></attributes></object>"
  "</child></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">True</property><property name=\"position\">1</prop"
  "erty></packing></child></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">1</property></packing></child></object></child><action-widgets>"
  "<action-widget response=\"0\">close-button</action-widget><action-widge"
  "t response=\"0\">help-button</action-widget></action-widgets></object><"
  "/interface>"
};

static const unsigned systray_dialog_ui_length = 12588u;

