/* automatically generated from directorymenu-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (directorymenu_dialog_ui)
#endif
#ifdef __GNUC__
static const char directorymenu_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char directorymenu_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">help-browser</property></object><object class=\"GtkImag"
  "e\" id=\"image2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">window-c"
  "lose</property></object><object class=\"XfceTitledDialog\" id=\"dialog\""
  "><property name=\"can_focus\">False</property><property name=\"title\" "
  "translatable=\"yes\">Directory Menu</property><property name=\"icon_nam"
  "e\">document-properties</property><property name=\"type_hint\">normal</"
  "property><child internal-child=\"vbox\"><object class=\"GtkBox\" id=\"d"
  "ialog-vbox2\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"orientation\">vertical</"
  "property><property name=\"spacing\">2</property><child internal-child=\""
  "action_area\"><object class=\"GtkButtonBox\" id=\"dialog-action_area2\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"layout_style\">end</property><child><"
  "object class=\"GtkButton\" id=\"close-button\"><property name=\"label\""
  " translatable=\"yes\">_Close</property><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "receives_default\">True</property><property name=\"image\">image2</prop"
  "erty><property name=\"use_underline\">True</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">False"
  "</property><property name=\"position\">0</property></packing></child><c"
  "hild><object class=\"GtkButton\" id=\"help-button\"><property name=\"la"
  "bel\" translatable=\"yes\">_Help</property><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">True</property><property nam"
  "e=\"receives_default\">True</property><property name=\"image\">image1</"
  "property><property name=\"use_underline\">True</property></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">F"
  "alse</property><property name=\"position\">1</property><property name=\""
  "secondary\">True</property></packing></child></object><packing><propert"
  "y name=\"expand\">False</property><property name=\"fill\">False</proper"
  "ty><property name=\"pack_type\">end</property><property name=\"position"
  "\">0</property></packing></child><child><object class=\"GtkBox\" id=\"v"
  "box1\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"border_width\">6</property><pro"
  "perty name=\"orientation\">vertical</property><property name=\"spacing\""
  ">6</property><child><object class=\"GtkFrame\" id=\"frame3\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"label_xalign\">0</property><property name=\"shad"
  "ow_type\">none</property><child><object class=\"GtkGrid\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"margin_left\">18</property><property name=\"row_spa"
  "cing\">6</property><property name=\"column_spacing\">12</property><chil"
  "d><object class=\"GtkFileChooserButton\" id=\"base-directory\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"hexpand\">True</property><property name=\"acti"
  "on\">select-folder</property><property name=\"local_only\">False</prope"
  "rty><property name=\"title\" translatable=\"yes\">Select A Directory</p"
  "roperty></object><packing><property name=\"left_attach\">1</property><p"
  "roperty name=\"top_attach\">0</property></packing></child><child><objec"
  "t class=\"GtkButton\" id=\"icon-button\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">True</property><property name="
  "\"receives_default\">True</property><property name=\"halign\">start</pr"
  "operty></object><packing><property name=\"left_attach\">1</property><pr"
  "operty name=\"top_attach\">1</property></packing></child><child><object"
  " class=\"GtkLabel\" id=\"label4\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"labe"
  "l\" translatable=\"yes\">_Icon:</property><property name=\"use_underlin"
  "e\">True</property><property name=\"xalign\">0</property></object><pack"
  "ing><property name=\"left_attach\">0</property><property name=\"top_att"
  "ach\">1</property></packing></child><child><object class=\"GtkLabel\" i"
  "d=\"label2\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"label\" translatable=\"yes"
  "\">_Base Directory:</property><property name=\"use_underline\">True</pr"
  "operty><property name=\"xalign\">0</property></object><packing><propert"
  "y name=\"left_attach\">0</property><property name=\"top_attach\">0</pro"
  "perty></packing></child></object></child><child type=\"label\"><object "
  "class=\"GtkLabel\" id=\"label1\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"label"
  "\" translatable=\"yes\">Appearance</property><attributes><attribute nam"
  "e=\"weight\" value=\"bold\"/></attributes></object></child></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkFrame\" id=\"frame1\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"label_xalign\">0</property><property name=\"shadow_type\">"
  "none</property><child><object class=\"GtkGrid\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"margin_left\">18</property><property name=\"row_spacing\">6</"
  "property><property name=\"column_spacing\">12</property><child><object "
  "class=\"GtkCheckButton\" id=\"hidden-files\"><property name=\"label\" t"
  "ranslatable=\"yes\">Show _hidden files</property><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"receives_default\">False</property><property name=\"use_under"
  "line\">True</property><property name=\"draw_indicator\">True</property>"
  "</object><packing><property name=\"left_attach\">0</property><property "
  "name=\"top_attach\">1</property><property name=\"width\">2</property></"
  "packing></child><child><object class=\"GtkEntry\" id=\"file-pattern\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">T"
  "rue</property><property name=\"tooltip_text\" translatable=\"yes\">Ente"
  "r a list of patterns that will be used to determine which files are vis"
  "ible in a directory. If you specify more than one pattern here, the lis"
  "t items must be separated with semicolons (e.g. *.txt;*.doc).</property"
  "><property name=\"invisible_char\">\342\200\242</property></object><pac"
  "king><property name=\"left_attach\">1</property><property name=\"top_at"
  "tach\">0</property></packing></child><child><object class=\"GtkLabel\" "
  "id=\"label7\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"label\" translatable=\"y"
  "es\">_File Pattern:</property><property name=\"use_underline\">True</pr"
  "operty><property name=\"xalign\">0</property></object><packing><propert"
  "y name=\"left_attach\">0</property><property name=\"top_attach\">0</pro"
  "perty></packing></child></object></child><child type=\"label\"><object "
  "class=\"GtkLabel\" id=\"label8\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"label"
  "\" translatable=\"yes\">Filtering</property><attributes><attribute name"
  "=\"weight\" value=\"bold\"/></attributes></object></child></object><pac"
  "king><property name=\"expand\">False</property><property name=\"fill\">"
  "True</property><property name=\"position\">1</property></packing></chil"
  "d></object><packing><property name=\"expand\">False</property><property"
  " name=\"fill\">True</property><property name=\"position\">1</property><"
  "/packing></child></object></child><action-widgets><action-widget respon"
  "se=\"0\">close-button</action-widget><action-widget response=\"0\">help"
  "-button</action-widget></action-widgets></object><object class=\"GtkSiz"
  "eGroup\" id=\"sizegroup1\"/></interface>"
};

static const unsigned directorymenu_dialog_ui_length = 7878u;

