/* automatically generated from windowmenu-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (windowmenu_dialog_ui)
#endif
#ifdef __GNUC__
static const char windowmenu_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char windowmenu_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">help-browser</property></object><object class=\"GtkImag"
  "e\" id=\"image2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">window-c"
  "lose</property></object><object class=\"GtkListStore\" id=\"style-model"
  "\"><columns><column type=\"gchararray\"/></columns><data><row><col id=\""
  "0\" translatable=\"yes\">Icon</col></row><row><col id=\"0\" translatabl"
  "e=\"yes\">Arrow</col></row></data></object><object class=\"XfceTitledDi"
  "alog\" id=\"dialog\"><property name=\"can_focus\">False</property><prop"
  "erty name=\"title\" translatable=\"yes\">Window Menu</property><propert"
  "y name=\"icon_name\">document-properties</property><property name=\"typ"
  "e_hint\">normal</property><child internal-child=\"vbox\"><object class="
  "\"GtkBox\" id=\"dialog-vbox2\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"orienta"
  "tion\">vertical</property><property name=\"spacing\">2</property><child"
  " internal-child=\"action_area\"><object class=\"GtkButtonBox\" id=\"dia"
  "log-action_area2\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"layout_style\">end<"
  "/property><child><object class=\"GtkButton\" id=\"close-button\"><prope"
  "rty name=\"label\" translatable=\"yes\">_Close</property><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"receives_default\">True</property><property name=\"im"
  "age\">image2</property><property name=\"use_underline\">True</property>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">False</property><property name=\"position\">0</property></"
  "packing></child><child><object class=\"GtkButton\" id=\"help-button\"><"
  "property name=\"label\" translatable=\"yes\">_Help</property><property "
  "name=\"visible\">True</property><property name=\"can_focus\">True</prop"
  "erty><property name=\"receives_default\">True</property><property name="
  "\"image\">image1</property><property name=\"use_underline\">True</prope"
  "rty></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">False</property><property name=\"position\">1</propert"
  "y><property name=\"secondary\">True</property></packing></child></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">False</property><property name=\"pack_type\">end</property><prope"
  "rty name=\"position\">0</property></packing></child><child><object clas"
  "s=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"border_width"
  "\">6</property><property name=\"orientation\">vertical</property><prope"
  "rty name=\"spacing\">6</property><child><object class=\"GtkFrame\" id=\""
  "frame3\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label_xalign\">0</property><p"
  "roperty name=\"shadow_type\">none</property><child><object class=\"GtkA"
  "lignment\" id=\"alignment3\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"left_padd"
  "ing\">12</property><child><object class=\"GtkBox\" id=\"vbox3\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"border_width\">6</property><property name=\"o"
  "rientation\">vertical</property><property name=\"spacing\">6</property>"
  "<child><object class=\"GtkBox\" id=\"hbox1\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"spacing\">12</property><child><object class=\"GtkLabel\" id=\"la"
  "bel5\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"label\" translatable=\"yes\">Bu"
  "tton layout:</property><property name=\"xalign\">0</property></object><"
  "packing><property name=\"expand\">False</property><property name=\"fill"
  "\">True</property><property name=\"position\">0</property></packing></c"
  "hild><child><object class=\"GtkComboBox\" id=\"style\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"model\">style-model</property><child><object class=\"Gt"
  "kCellRendererText\" id=\"cellrenderertext1\"/><attributes><attribute na"
  "me=\"text\">0</attribute></attributes></child></object><packing><proper"
  "ty name=\"expand\">True</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">1</property></packing></child></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkCheckButton\" id=\"workspace-actions\"><pr"
  "operty name=\"label\" translatable=\"yes\">Show workspace a_ctions</pro"
  "perty><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">True</property><property name=\"receives_default\">False</propert"
  "y><property name=\"use_underline\">True</property><property name=\"draw"
  "_indicator\">True</property></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">1</property></packing></child><child><object class=\"GtkCh"
  "eckButton\" id=\"workspace-names\"><property name=\"label\" translatabl"
  "e=\"yes\">Show workspace _names</property><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">True</property><property name"
  "=\"receives_default\">False</property><property name=\"use_underline\">"
  "True</property><property name=\"draw_indicator\">True</property></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">True</property><property name=\"position\">2</property></packing>"
  "</child><child><object class=\"GtkCheckButton\" id=\"urgentcy-notificat"
  "ion\"><property name=\"label\" translatable=\"yes\">Enable _urgency not"
  "ification</property><property name=\"visible\">True</property><property"
  " name=\"can_focus\">True</property><property name=\"receives_default\">"
  "False</property><property name=\"use_underline\">True</property><proper"
  "ty name=\"draw_indicator\">True</property></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">True</property><"
  "property name=\"position\">3</property></packing></child></object></chi"
  "ld></object></child><child type=\"label\"><object class=\"GtkLabel\" id"
  "=\"label1\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"label\" translatable=\"yes"
  "\">Appearance</property><attributes><attribute name=\"weight\" value=\""
  "bold\"/></attributes></object></child></object><packing><property name="
  "\"expand\">False</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">0</property></packing></child><child><object cla"
  "ss=\"GtkFrame\" id=\"frame1\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"label_xa"
  "lign\">0</property><property name=\"shadow_type\">none</property><child"
  "><object class=\"GtkAlignment\" id=\"alignment1\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"left_padding\">12</property><child><object class=\"GtkBox\""
  " id=\"vbox2\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"border_width\">6</proper"
  "ty><property name=\"orientation\">vertical</property><property name=\"s"
  "pacing\">6</property><child><object class=\"GtkCheckButton\" id=\"all-w"
  "orkspaces\"><property name=\"label\" translatable=\"yes\">Show windows "
  "from _all workspaces</property><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">True</property><property name=\"receives"
  "_default\">False</property><property name=\"use_underline\">True</prope"
  "rty><property name=\"draw_indicator\">True</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">True<"
  "/property><property name=\"position\">0</property></packing></child></o"
  "bject></child></object></child><child type=\"label\"><object class=\"Gt"
  "kLabel\" id=\"label3\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"label\" transla"
  "table=\"yes\">Filtering</property><attributes><attribute name=\"weight\""
  " value=\"bold\"/></attributes></object></child></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">1</property></packing></child></object>"
  "<packing><property name=\"expand\">False</property><property name=\"fil"
  "l\">True</property><property name=\"position\">1</property></packing></"
  "child></object></child><action-widgets><action-widget response=\"0\">cl"
  "ose-button</action-widget><action-widget response=\"0\">help-button</ac"
  "tion-widget></action-widgets></object></interface>"
};

static const unsigned windowmenu_dialog_ui_length = 8630u;

